@@ -32,6 +32,7 @@
 #include <sstream>
 #include <vector>
 
+#include "Schedule.hh"
 #include "compatibility.hh"
 #include "compile.hh"
 #include "compile_scal.hh"
@@ -42,13 +43,19 @@
 #include "prim2.hh"
 #include "recursivness.hh"
 #include "sharing.hh"
+#include "sigDependenciesGraph.hh"
+#include "sigNewConstantPropagation.hh"
 #include "sigPromotion.hh"
+#include "sigRecursiveDependencies.hh"
+#include "sigRetiming.hh"
 #include "sigToGraph.hh"
 #include "sigprint.hh"
 #include "sigtype.hh"
 #include "timing.hh"
 #include "xtended.hh"
 
+#undef TRACE
+
 // Old delays are supposed to work while new delays are in progress
 #define OLDDELAY 0
 
@@ -107,7 +114,7 @@ Tree ScalarCompiler::prepare(Tree LS)
         throw faustexception("Dump signal type finished...\n");
     }
     // No more table privatisation
-    Tree L2 = L1;
+    Tree L2 = newConstantPropagation(L1);
 
     startTiming("conditionAnnotation");
     conditionAnnotation(L2);
@@ -134,6 +141,11 @@ Tree ScalarCompiler::prepare(Tree LS)
     endTiming("prepare");
 
     if (gGlobal->gDrawSignals) {
+        if (gGlobal->gDrawRetiming) {
+            Tree     L3 = sigRetiming(L2);
+            ofstream dotfile(subst("$0-rtsig.dot", gGlobal->makeDrawPath()).c_str());
+            sigToGraph(L3, dotfile);
+        }
         ofstream dotfile(subst("$0-sig.dot", gGlobal->makeDrawPath()).c_str());
         sigToGraph(L2, dotfile);
     }
@@ -175,7 +187,9 @@ Tree ScalarCompiler::prepare2(Tree L0)
 
 string ScalarCompiler::dnf2code(Tree cc)
 {
-    if (cc == gGlobal->nil) return "";
+    if (cc == gGlobal->nil) {
+        return "";
+    }
     Tree c1 = hd(cc);
     cc      = tl(cc);
     if (cc == gGlobal->nil) {
@@ -187,7 +201,9 @@ string ScalarCompiler::dnf2code(Tree cc)
 
 string ScalarCompiler::and2code(Tree cs)
 {
-    if (cs == gGlobal->nil) return "";
+    if (cs == gGlobal->nil) {
+        return "";
+    }
     Tree c1 = hd(cs);
     cs      = tl(cs);
     if (cs == gGlobal->nil) {
@@ -199,7 +215,9 @@ string ScalarCompiler::and2code(Tree cs)
 
 string ScalarCompiler::cnf2code(Tree cs)
 {
-    if (cs == gGlobal->nil) return "";
+    if (cs == gGlobal->nil) {
+        return "";
+    }
     Tree c1 = hd(cs);
     cs      = tl(cs);
     if (cs == gGlobal->nil) {
@@ -211,7 +229,9 @@ string ScalarCompiler::cnf2code(Tree cs)
 
 string ScalarCompiler::or2code(Tree cs)
 {
-    if (cs == gGlobal->nil) return "";
+    if (cs == gGlobal->nil) {
+        return "";
+    }
     Tree c1 = hd(cs);
     cs      = tl(cs);
     if (cs == gGlobal->nil) {
@@ -248,7 +268,8 @@ void ScalarCompiler::conditionStatistics(Tree l)
 
 void ScalarCompiler::conditionStatistics(Tree l)
 {
-    map<Tree, int> fConditionStatistics;  // used with the new X,Y:enable --> sigEnable(X*Y,Y>0) primitive
+    map<Tree, int>
+        fConditionStatistics;  // used with the new X,Y:enable --> sigEnable(X*Y,Y>0) primitive
     for (const auto& p : fConditionProperty) {
         for (Tree lc = p.second; !isNil(lc); lc = tl(lc)) {
             fConditionStatistics[hd(lc)]++;
@@ -299,9 +320,11 @@ void ScalarCompiler::conditionAnnotation(Tree t, Tree nc)
         // general annotation case
         // Annotate the sub signals with nc
         tvec subsig;
-        int n = getSubSignals(t, subsig);
+        int  n = getSubSignals(t, subsig);
         if (n > 0 && !isSigGen(t)) {
-            for (int i = 0; i < n; i++) conditionAnnotation(subsig[i], nc);
+            for (int i = 0; i < n; i++) {
+                conditionAnnotation(subsig[i], nc);
+            }
         }
     }
 }
@@ -332,8 +355,8 @@ string ScalarCompiler::setCompiledExpression(Tree sig, const string& cexp)
     string old;
     if (fCompileProperty.get(sig, old) && (old != cexp)) {
         // stringstream error;
-        // error << "ERROR already a compiled expression attached : " << old << " replaced by " << cexp << endl;
-        // throw faustexception(error.str());
+        // error << "ERROR already a compiled expression attached : " << old << " replaced by " <<
+        // cexp << endl; throw faustexception(error.str());
     }
 
     fCompileProperty.set(sig, cexp);
@@ -371,6 +394,23 @@ bool ScalarCompiler::getVectorNameProperty(Tree sig, string& vecname)
     return fVectorProperty.get(sig, vecname);
 }
 
+/**
+ * Make sure sig has a vector name property, if not use the one passed in parameter.
+ * @param a name in case not already named
+ * @param sig the signal expression.
+ * @return the vector name associated with sig
+ */
+
+std::string ScalarCompiler::ensureVectorNameProperty(const std::string altname, Tree sig)
+{
+    std::string vecname;
+    if (!getVectorNameProperty(sig, vecname)) {
+        vecname = altname;
+        setVectorNameProperty(sig, vecname);
+    }
+    return vecname;
+}
+
 /**
  * Compile a signal
  * @param sig the signal expression to compile.
@@ -383,14 +423,26 @@ string ScalarCompiler::CS(Tree sig)
     string code;
 
     if (!getCompiledExpression(sig, code)) {
-        // not compiled yet
-        /*
-         if (getRecursivness(sig) != contextRecursivness.get()) {
-            contextRecursivness.set(getRecursivness(sig));
-         }
-         */
+// not compiled yet
+/*
+ if (getRecursivness(sig) != contextRecursivness.get()) {
+    contextRecursivness.set(getRecursivness(sig));
+ }
+ */
+#ifdef TRACE
+        int step = gGlobal->gSTEP;
+        std::cerr << "\n"
+                  << step << " [order: " << fScheduleOrder[sig] << "] "
+                  << "::" << sig << "\t: generateCode( " << ppsig(sig, 10) << " )" << std::endl;
+#endif
         code = generateCode(sig);
         setCompiledExpression(sig, code);
+
+#ifdef TRACE
+        std::cerr << "\n"
+                  << step << " [order: " << fScheduleOrder[sig] << "] "
+                  << "::" << sig << "\t: ============> " << code << std::endl;
+#endif
     }
     return code;
 }
@@ -415,10 +467,54 @@ void ScalarCompiler::compileMultiSignal(Tree L)
         fClass->addZone3(subst("$1* output$0 = &output[$0][index]; // Zone 3", T(i), xfloat()));
     }
 
+    // force a specific compilation order
+    auto G = immediateGraph(L);
+    auto S = dfschedule(G);
+    // register the compilation order S for debug purposes
+    {
+        int jj = 0;
+        for (auto& s : S.elements()) {
+            int  pnum;
+            Tree rg;
+            fScheduleOrder[s] = ++jj;
+#if 0
+            if (isProj(s, &pnum, rg)) {
+                if (isSignalRecursive(s)) {
+                    // std::cerr << jj << " proj " << pnum << " of " << *rg << " is recursive"
+                    //<< std::endl;
+                } else {
+                    std::cerr << jj << " proj " << pnum << " of " << *rg
+                              << " is NOT recursive and could be simplified: "
+                              /*<< ppsig(getProjDefinition(s))*/
+                              << std::endl;
+                }
+            }
+#endif
+        }
+    }
+
+#ifdef TRACE
+    std::cerr << "\nBEFORE COMPILING" << std::endl;
+    std::cerr << G << std::endl;
+    std::cerr << S << std::endl;
+
+    std::cerr << "\nCOMPILE SCHEDULE" << std::endl;
+#endif
+    // gGlobal->gSTEP = 0;
+    for (auto& s : S.elements()) {
+        if (isNil(s)) {
+            std::cerr << "NOT SUPPOSED TO HAPPEN: We have a Nil in the schedule !" << std::endl;
+            faustassert(false);
+        }
+        int lSTEP = gGlobal->gSTEP;  // conveninient for debug
+        CS(s);
+        gGlobal->gSTEP++;
+    }
+
     for (int i = 0; isList(L); L = tl(L), i++) {
-        Tree sig = hd(L);
-        fClass->addExecCode(Statement(
-            "", subst("output$0[i] = $2($1);  // Zone Exec Code", T(i), generateCacheCode(sig, CS(sig)), xcast())));
+        Tree s = hd(L);
+        fClass->addExecCode(Statement("", subst("output$0[i] = $2($1);  // Zone Exec Code", T(i),
+                                                generateCacheCode(s, CS(s)), xcast())));
     }
 
     generateMetaData();
@@ -444,6 +540,38 @@ void ScalarCompiler::compileSingleSignal(Tree sig)
 {
     // contextor recursivness(0);
     sig = prepare2(sig);  // optimize and annotate expression
+
+#ifdef TRACE
+    std::cerr << "\nSTART COMPILING SINGLE SIGNAL: " << ppsig(sig, 20) << std::endl;
+#endif
+    // force a specific compilation order
+    auto G = immediateGraph(cons(sig, gGlobal->nil));
+    auto S = dfschedule(G);
+#ifdef TRACE
+    std::cerr << "\nBEFORE COMPILING SINGLE SIGNAL" << std::endl;
+    std::cerr << G << std::endl;
+    std::cerr << S << std::endl;
+#endif
+    // register the compilation order S for debug purposes
+    {
+        int jj = 1000;
+        for (auto& s : S.elements()) {
+            fScheduleOrder[s] += ++jj;
+        }
+    }
+#ifdef TRACE
+    std::cerr << "\nCOMPILE SINGLE SIGNAL SCHEDULE" << std::endl;
+#endif
+    for (auto& s : S.elements()) {
+        if (isNil(s)) {
+            std::cerr << "NOT SUPPOSED TO HAPPEN: We have a Nil in the schedule !" << std::endl;
+            faustassert(false);
+        }
+        int lSTEP = gGlobal->gSTEP;  // convenient for debug
+        CS(s);
+        gGlobal->gSTEP++;
+    }
+
     fClass->addExecCode(Statement("", subst("output[i] = $0;", CS(sig))));
     generateUserInterfaceTree(fUITree.prepareUserInterfaceTree(), true);
     generateMacroInterfaceTree("", fUITree.prepareUserInterfaceTree());
@@ -465,12 +593,6 @@ void ScalarCompiler::compileSingleSignal(Tree sig)
 
 string ScalarCompiler::generateCode(Tree sig)
 {
-#if 0
-    fprintf(stderr, "CALL generateCode(");
-    printSignal(sig, stderr);
-    fprintf(stderr, ")\n");
-#endif
-
     int     i;
     int64_t i64;
     double  r;
@@ -557,8 +679,8 @@ string ScalarCompiler::generateCode(Tree sig)
     } else if (isSigSoundfileRate(sig, sf, x)) {
         return generateCacheCode(sig, subst("$0cache->fSR[$1]", CS(sf), CS(x)));
     } else if (isSigSoundfileBuffer(sig, sf, x, y, z)) {
-        return generateCacheCode(sig, subst("(($1)$0cache->fBuffers)[$2][$0cache->fOffset[$3]+$4]", CS(sf),
-                                            ifloatptrptr(), CS(x), CS(y), CS(z)));
+        return generateCacheCode(sig, subst("(($1)$0cache->fBuffers)[$2][$0cache->fOffset[$3]+$4]",
+                                            CS(sf), ifloatptrptr(), CS(x), CS(y), CS(z)));
     }
 
     else if (isSigAttach(sig, x, y)) {
@@ -572,7 +694,7 @@ string ScalarCompiler::generateCode(Tree sig)
     }
     /* we should not have any control at this stage */
     else {
-        cerr << "ASSERT : when compiling, unrecognized signal : " << ppsig(sig, MAX_ERROR_SIZE) << endl;
+        cerr << "ASSERT : when compiling, unrecognized signal : " << *sig << endl;
         faustassert(false);
     }
     return "error in generated code";
@@ -663,7 +785,7 @@ string ScalarCompiler::generateBinOp(Tree sig, int opcode, Tree arg1, Tree arg2)
         } else {
             return subst("-($0)", res);
         }
-    // Special case for a1*-1
+        // Special case for a1*-1
     } else if ((opcode == kMul) && isMinusOne(arg2)) {
         std::string res = CS(arg1);
         if ((res[0] == '(') || (res[0] == 'f') || (res[0] == 'i')) {
@@ -672,7 +794,8 @@ string ScalarCompiler::generateBinOp(Tree sig, int opcode, Tree arg1, Tree arg2)
             return subst("-($0)", res);
         }
     } else {
-        return generateCacheCode(sig, subst("($0 $1 $2)", CS(arg1), gBinOpTable[opcode]->fName, CS(arg2)));
+        return generateCacheCode(
+            sig, subst("($0 $1 $2)", CS(arg1), gBinOpTable[opcode]->fName, CS(arg2)));
     }
 }
 
@@ -746,8 +869,8 @@ string ScalarCompiler::generateCacheCode(Tree sig, const string& exp)
     if (o->getMaxDelay() > 0) {
         getTypedNames(getCertifiedSigType(sig), "Vec", ctype, vname);
         if (sharing > 1) {
-            return generateDelayVec(sig, generateVariableStore(sig, exp), ctype, vname, o->getMaxDelay(),
-                                    o->getDelayCount());
+            return generateDelayVec(sig, generateVariableStore(sig, exp), ctype, vname,
+                                    o->getMaxDelay(), o->getDelayCount());
         } else {
             return generateDelayVec(sig, exp, ctype, vname, o->getMaxDelay(), o->getDelayCount());
         }
@@ -782,15 +905,15 @@ string ScalarCompiler::forceCacheCode(Tree sig, const string& exp)
     // check for expression occuring in delays
     if (o->getMaxDelay() > 0) {
         getTypedNames(getCertifiedSigType(sig), "Vec", ctype, vname);
-        return generateDelayVec(sig, generateVariableStore(sig, exp), ctype, vname, o->getMaxDelay(),
-                                o->getDelayCount());
+        return generateDelayVec(sig, generateVariableStore(sig, exp), ctype, vname,
+                                o->getMaxDelay(), o->getDelayCount());
     } else {
         return generateVariableStore(sig, exp);
     }
 }
 
-// Definition of variables: Const (computed at init time), Slow (computed at control rate) and "Temp" (computed at
-// sample rate)
+// Definition of variables: Const (computed at init time), Slow (computed at control rate) and
+// "Temp" (computed at sample rate)
 string ScalarCompiler::generateVariableStore(Tree sig, const string& exp)
 {
     string       vname, vname_perm, ctype;
@@ -801,26 +924,32 @@ string ScalarCompiler::generateVariableStore(Tree sig, const string& exp)
     switch (t->variability()) {
         case kKonst:
             getTypedNames(t, "Const", ctype, vname);
-            // The variable is used in compute (kBlock or kSamp), so define is as a field in the DSP struct
+            // The variable is used in compute (kBlock or kSamp), so define is as a field in the DSP
+            // struct
             if (o->getOccurrence(kBlock) || o->getOccurrence(kSamp)) {
-                fClass->addDeclCode(subst("$0 \t$1;", ctype, vname));
-                fClass->addInitCode(subst("$0 = $1;", vname, exp));
+                fClass->addDeclCode(subst("$0 \t$1; // step: $2", ctype, vname, T(gGlobal->gSTEP)));
+                fClass->addInitCode(subst("$0 = $1; // step: $2", vname, exp, T(gGlobal->gSTEP)));
             } else {
                 // Otherwise it can stay as a local variable
-                fClass->addInitCode(subst("$0 \t$1 = $2;", ctype, vname, exp));
+                // fClass->addInitCode(subst("$0 \t$1 = $2; // step: $3", ctype, vname, exp,
+                // T(gGlobal->gSTEP))); FIX Bug const ???
+                fClass->addDeclCode(subst("$0 \t$1; // step: $2", ctype, vname, T(gGlobal->gSTEP)));
+                fClass->addInitCode(subst("$0 = $1; // step: $2", vname, exp, T(gGlobal->gSTEP)));
             }
             break;
 
         case kBlock:
             getTypedNames(t, "Slow", ctype, vname);
             fClass->addFirstPrivateDecl(vname);
-            fClass->addZone2(subst("$0 \t$1 = $2;", ctype, vname, exp));
+            fClass->addZone2(
+                subst("$0 \t$1 = $2; // step: $3", ctype, vname, exp, T(gGlobal->gSTEP)));
             break;
 
         case kSamp:
             getTypedNames(t, "Temp", ctype, vname);
             if (getConditionCode(sig) == "") {
-                fClass->addExecCode(Statement("", subst("$0 \t$1 = $2;", ctype, vname, exp)));
+                fClass->addExecCode(Statement(
+                    "", subst("$0 \t$1 = $2; // step: $3", ctype, vname, exp, T(gGlobal->gSTEP))));
             } else {
                 getTypedNames(t, "TempPerm", ctype, vname_perm);
                 // need to be preserved because of new enable and control primitives
@@ -829,7 +958,8 @@ string ScalarCompiler::generateVariableStore(Tree sig, const string& exp)
                 // copy the object variable to the local one
                 fClass->addZone2(subst("$0 \t$1 = $2;", ctype, vname, vname_perm));
                 // execute the code
-                fClass->addExecCode(Statement(getConditionCode(sig), subst("$0 = $1;", vname, exp)));
+                fClass->addExecCode(
+                    Statement(getConditionCode(sig), subst("$0 = $1;", vname, exp)));
                 // copy the local variable to the object one
                 fClass->addZone4(subst("$0 = $1;", vname_perm, vname));
             }
@@ -912,7 +1042,8 @@ string ScalarCompiler::generateHSlider(Tree sig, Tree path, Tree cur, Tree min,
     return generateCacheCode(sig, subst("$1($0)", varname, ifloat()));
 }
 
-string ScalarCompiler::generateNumEntry(Tree sig, Tree path, Tree cur, Tree min, Tree max, Tree step)
+string ScalarCompiler::generateNumEntry(Tree sig, Tree path, Tree cur, Tree min, Tree max,
+                                        Tree step)
 {
     string varname = getFreshID("fentry");
     fClass->addDeclCode(subst("$1 \t$0;", varname, xfloat()));
@@ -994,7 +1125,7 @@ string ScalarCompiler::generateSoundfile(Tree sig, Tree path)
 }
 
 /*****************************************************************************
- TABLES
+                                TABLES
  *****************************************************************************/
 
 /*----------------------------------------------------------------------------
@@ -1096,15 +1227,16 @@ string ScalarCompiler::generateStaticTable(Tree sig, Tree tsize, Tree content)
     getTypedNames(getCertifiedSigType(content), "tbl", ctype, vname);
 
     // Table declaration
-    if (gGlobal->gMemoryManager) {
+    if (gGlobal->gMemoryManager >= 0) {
         fClass->addDeclCode(subst("static $0* \t$1;", ctype, vname));
         fClass->addStaticFields(subst("$0* \t$1::$2 = 0;", ctype, fClass->getClassName(), vname));
-        fClass->addStaticInitCode(
-            subst("$0 = static_cast<$1*>(fManager->allocate(sizeof($1) * $2));", vname, ctype, T(size)));
+        fClass->addStaticInitCode(subst(
+            "$0 = static_cast<$1*>(fManager->allocate(sizeof($1) * $2));", vname, ctype, T(size)));
         fClass->addStaticDestroyCode(subst("fManager->destroy($0);", vname));
     } else {
         fClass->addDeclCode(subst("static $0 \t$1[$2];", ctype, vname, T(size)));
-        fClass->addStaticFields(subst("$0 \t$1::$2[$3];", ctype, fClass->getClassName(), vname, T(size)));
+        fClass->addStaticFields(
+            subst("$0 \t$1::$2[$3];", ctype, fClass->getClassName(), vname, T(size)));
     }
 
     // Initialization of the content generator
@@ -1123,15 +1255,20 @@ string ScalarCompiler::generateStaticTable(Tree sig, Tree tsize, Tree content)
 string ScalarCompiler::generateWRTbl(Tree sig, Tree size, Tree gen, Tree wi, Tree ws)
 {
     string tblName = generateTable(sig, size, gen);
+    // std::cerr << "wi = " << *wi << " ws = " << *ws << "\n";
+    std::string swi = CS(wi);
+    std::string sws = CS(ws);
+
     switch (getCertifiedSigType(sig)->variability()) {
         case kKonst:
-            fClass->addInitCode(subst("$0[$1] = $2;", tblName, CS(wi), CS(ws)));
+            fClass->addInitCode(subst("$0[$1] = $2;", tblName, swi, sws));
             break;
         case kBlock:
-            fClass->addZone2(subst("$0[$1] = $2;", tblName, CS(wi), CS(ws)));
+            fClass->addZone2(subst("$0[$1] = $2;", tblName, swi, sws));
             break;
         default:
-            fClass->addExecCode(Statement(getConditionCode(sig), subst("$0[$1] = $2;", tblName, CS(wi), CS(ws))));
+            fClass->addExecCode(
+                Statement(getConditionCode(sig), subst("$0[$1] = $2;", tblName, swi, sws)));
             break;
     }
 
@@ -1146,6 +1283,11 @@ string ScalarCompiler::generateWRTbl(Tree sig, Tree size, Tree gen, Tree wi, Tre
 string ScalarCompiler::generateRDTbl(Tree sig, Tree tbl, Tree ri)
 {
     // Test the special case of a read only table that can be compiled as a static member
+    Occurrences* o = fOccMarkup->retrieve(sig);
+#ifdef TRACE
+    std::cerr << "generateRDTbl : " << sig << "; mxd=" << o->getMaxDelay()
+              << "; delay count=" << o->getDelayCount() << "\n";
+#endif
     Tree size, gen;
     if (isSigWRTbl(tbl, size, gen)) {
         // rdtable
@@ -1153,7 +1295,10 @@ string ScalarCompiler::generateRDTbl(Tree sig, Tree tbl, Tree ri)
         if (!getCompiledExpression(tbl, tblname)) {
             tblname = setCompiledExpression(tbl, generateStaticTable(tbl, size, gen));
         }
-        return generateCacheCode(sig, subst("$0[$1]", tblname, CS(ri)));
+        std::string ricode = CS(ri);
+        std::string instr  = subst("$0[$1]", tblname, ricode);
+        std::string result = generateCacheCode(sig, instr);
+        return result;
     } else {
         // rwtable
         return generateCacheCode(sig, subst("$0[$1]", CS(tbl), CS(ri)));
@@ -1169,23 +1314,53 @@ string ScalarCompiler::generateRDTbl(Tree sig, Tree tbl, Tree ri)
  */
 string ScalarCompiler::generateRecProj(Tree sig, Tree r, int i)
 {
-    string vname;
+    string pname, ctype;
     Tree   var, le;
 
-    if (!getVectorNameProperty(sig, vname)) {
-        faustassert(isRec(r, var, le));
-        generateRec(r, var, le);
-        faustassert(getVectorNameProperty(sig, vname));
-    }
-    return "[[UNUSED EXP]]";  // make sure the resulting expression is never used in the generated code
+    // if (!getVectorNameProperty(sig, vname)) {
+    //     faustassert(isRec(r, var, le));
+    //     // generateRec(r, var, le);
+    //     // faustassert(getVectorNameProperty(sig, vname));
+    //     std::string ctype;
+    //     Type        ty = getCertifiedSigType(sig);
+    //     getTypedNames(ty, "Reec", ctype, vname);
+    //     setVectorNameProperty(sig, vname);
+    //     int  delay = fOccMarkup->retrieve(sig)->getMaxDelay();
+    //     int  count = fOccMarkup->retrieve(sig)->getDelayCount();
+    //     bool mono  = isSigSimpleRec(sig);
+    //     Tree def   = nth(le, i);
+    //     fClass->addDeclCode(subst("// Recursion delay $0 is of type $1", vname,
+    //     nameDelayType(analyzeDelayType(sig)))); fClass->addDeclCode(subst("// While its
+    //     definition is of type $0", nameDelayType(analyzeDelayType(def))));
+    //     generateDelayLine(analyzeDelayType(sig), ctype, vname, delay, count, mono, CS(def),
+    //     getConditionCode(def));
+    // }
+
+    Type ty = getCertifiedSigType(sig);
+    getTypedNames(ty, "Riiic", ctype, pname);
+    string vecname = ensureVectorNameProperty(pname, sig);
+    int    delay   = fOccMarkup->retrieve(sig)->getMaxDelay();
+    int    count   = fOccMarkup->retrieve(sig)->getDelayCount();
+    bool   mono    = isSigSimpleRec(sig);
+
+    faustassert(isRec(r, var, le));
+    Tree def = nth(le, i);
+    fClass->addDeclCode(subst("// Recursion delay $0 is of type $1", vecname,
+                              nameDelayType(analyzeDelayType(sig))));
+    fClass->addDeclCode(
+        subst("// While its definition is of type $0", nameDelayType(analyzeDelayType(def))));
+    std::string dl0 = generateDelayLine(analyzeDelayType(sig), ctype, vecname, delay, count, mono,
+                                        CS(def), getConditionCode(def));
+
+    return dl0;
 }
 
 /**
  * @brief Check if sig is a simple recursive signal that can be expressed using a single variable
  *
  * @param sig the signal to analyse, typically proj(i,X)
- * @return true if sig is of type x = f(x') and x' is used only once. In this case the same variable can be used both
- * for x and x'
+ * @return true if sig is of type x = f(x') and x' is used only once. In this case the same variable
+ * can be used both for x and x'
  * @return false
  */
 bool ScalarCompiler::isSigSimpleRec(Tree sig)
@@ -1215,8 +1390,8 @@ bool ScalarCompiler::isSigSimpleRec(Tree sig)
 }
 
 /**
- * @brief indicate best delay implementation type for a signal according to its max delay and various compilation
- * options
+ * @brief indicate best delay implementation type for a signal according to its max delay and
+ * various compilation options
  *
  * @param sig
  * @return DelayType
@@ -1227,7 +1402,7 @@ DelayType ScalarCompiler::analyzeDelayType(Tree sig)
     faustassert(occ != nullptr);
     int mxd   = occ->getMaxDelay();
     int count = occ->getDelayCount();
-    
+
     if (mxd == 0) {
         return DelayType::kZeroDelay;
     }
@@ -1262,6 +1437,8 @@ DelayType ScalarCompiler::analyzeDelayType(Tree sig)
  */
 void ScalarCompiler::generateRec(Tree sig, Tree var, Tree le)
 {
+    faustassert(false);
+
     int N = len(le);
 
     vector<bool>   used(N);
@@ -1295,11 +1472,12 @@ void ScalarCompiler::generateRec(Tree sig, Tree var, Tree le)
     for (int i = 0; i < N; i++) {
         if (used[i]) {
             Tree def = nth(le, i);
-            fClass->addDeclCode(
-                subst("// Recursion delay $0 is of type $1", vname[i], nameDelayType(analyzeDelayType(exp[i]))));
-            fClass->addDeclCode(subst("// While its definition is of type $0", nameDelayType(analyzeDelayType(def))));
-            generateDelayLine(analyzeDelayType(exp[i]), ctype[i], vname[i], delay[i], count[i], mono[i], CS(def),
-                              getConditionCode(def));
+            fClass->addDeclCode(subst("// Recursion delay $0 is of type $1", vname[i],
+                                      nameDelayType(analyzeDelayType(exp[i]))));
+            fClass->addDeclCode(subst("// While its definition is of type $0",
+                                      nameDelayType(analyzeDelayType(def))));
+            generateDelayLine(analyzeDelayType(exp[i]), ctype[i], vname[i], delay[i], count[i],
+                              mono[i], CS(def), getConditionCode(def));
         }
     }
 }
@@ -1327,7 +1505,8 @@ string ScalarCompiler::generatePrefix(Tree sig, Tree x, Tree e)
     fClass->addDeclCode(subst("$0 \t$1;", type, vperm));
     fClass->addInitCode(subst("$0 = $1;", vperm, CS(x)));
 
-    fClass->addExecCode(Statement(getConditionCode(sig), subst("$0 \t$1 = $2;", type, vtemp, vperm)));
+    fClass->addExecCode(
+        Statement(getConditionCode(sig), subst("$0 \t$1 = $2;", type, vtemp, vperm)));
 
     /*
     string res = CS(e);
@@ -1438,44 +1617,49 @@ string ScalarCompiler::generateDelayAccess(Tree sig, Tree exp, Tree delay)
         return generateCacheCode(sig, subst("$0[$1]", vecname, generateIotaCache(idx)));
     }
 #else
-    string    code = CS(exp);  // ensure exp is compiled to have a vector name
-    int       mxd  = fOccMarkup->retrieve(exp)->getMaxDelay();
-    DelayType dt   = analyzeDelayType(exp);
-    string    vecname;
-    if (getVectorNameProperty(exp, vecname)) {
-        switch (dt) {
-                
-            case DelayType::kNotADelay:
-                faustexception("Try to compile has a delay something that is not a delay");
-                return "";
-                
-            case DelayType::kZeroDelay:
-                return vecname;
+    // FIX: We don't compile the delayed signal anymore. This is done by the general scheduling.
+    // But we make sure the delayed signal has a vector name.
 
-            case DelayType::kMonoDelay:
-                return vecname;
+    // string    code = CS(exp);  // ensure exp is compiled to have a vector name
+    std::string ctype, pname;
+    getTypedNames(getCertifiedSigType(sig), "Veeec", ctype, pname);
+    string    vecname = ensureVectorNameProperty(pname, exp);
+    int       mxd     = fOccMarkup->retrieve(exp)->getMaxDelay();
+    DelayType dt      = analyzeDelayType(exp);
+#ifdef TRACE
+    std::cerr << "\nDELAYED: We expect this delayed signal to be compiled elsewhere at step "
+              << fScheduleOrder[exp] << " -- " << exp << " :: " << ppsig(exp, 10) << std::endl;
+#endif
+    std::string result;
+    switch (dt) {
+        case DelayType::kNotADelay:
+            faustexception("Try to compile has a delay something that is not a delay");
+            result = "";
+            break;
 
-            case DelayType::kSingleDelay:
-            case DelayType::kCopyDelay:
-            case DelayType::kDenseDelay:
-                return generateCacheCode(sig, subst("$0[$1]", vecname, CS(delay)));
+        case DelayType::kZeroDelay:
+            result = vecname;
+            break;
 
-            case DelayType::kMaskRingDelay:
-            case DelayType::kSelectRingDelay:
-                int         N   = pow2limit(mxd + 1);
-                std::string idx = subst("(IOTA-$0)&$1", CS(delay), T(N - 1));
-                return generateCacheCode(sig, subst("$0[$1]", vecname, generateIotaCache(idx)));
-        }
-    } else {
-        if (mxd == 0) {
-            // cerr << "it is a pure zero delay : " << code << endl;
-            return code;
-        } else {
-            cerr << "ASSERT : no vector name for : " << ppsig(exp, MAX_ERROR_SIZE) << endl;
-            faustassert(false);
-            return "";
-        }
+        case DelayType::kMonoDelay:
+            result = vecname;
+            break;
+
+        case DelayType::kSingleDelay:
+        case DelayType::kCopyDelay:
+        case DelayType::kDenseDelay:
+            result = subst("$0[$1]", vecname, CS(delay));
+            break;
+
+        case DelayType::kMaskRingDelay:
+        case DelayType::kSelectRingDelay:
+            int         N   = pow2limit(mxd + 1);
+            std::string idx = subst("(IOTA-$0)&$1", CS(delay), T(N - 1));
+            result          = subst("$0[$1]", vecname, generateIotaCache(idx));
+            break;
     }
+    return generateCacheCode(sig, result);
+
 #endif
 }
 
@@ -1483,8 +1667,8 @@ string ScalarCompiler::generateDelayAccess(Tree sig, Tree exp, Tree delay)
  * Generate code for the delay mechanism. The generated code depend of the
  * maximum delay attached to exp and the "less temporaries" switch
  */
-string ScalarCompiler::generateDelayVec(Tree sig, const string& exp, const string& ctype, const string& vname, int mxd,
-                                        int count)
+string ScalarCompiler::generateDelayVec(Tree sig, const string& exp, const string& ctype,
+                                        const string& vname, int mxd, int count)
 {
     string s = generateDelayVecNoTemp(sig, exp, ctype, vname, mxd, count);
     if (getCertifiedSigType(sig)->variability() < kSamp) {
@@ -1508,18 +1692,20 @@ string ScalarCompiler::generateDelayVec(Tree sig, const string& exp, const strin
     fClass->addPostCode(Statement(ccs, g.advance()));
     fClass->addZone3Post(g.copyLocalToGlobal());
 */
-string ScalarCompiler::generateDelayVecNoTemp(Tree sig, const string& exp, const string& ctype, const string& vname,
-                                              int mxd, int count)
+string ScalarCompiler::generateDelayVecNoTemp(Tree sig, const string& exp, const string& ctype,
+                                              const string& pname, int mxd, int count)
 {
     faustassert(mxd > 0);
 
-    bool mono = isSigSimpleRec(sig);
+    // We make sure to use the vector name associated with signal, or we provide one
+    std::string vecname = ensureVectorNameProperty(pname, sig);
+    bool        mono    = isSigSimpleRec(sig);
     // bool odocc = fOccMarkup->retrieve(sig)->hasOutDelayOccurrences();
     string    ccs = getConditionCode(sig);
     DelayType dt  = analyzeDelayType(sig);
     // fClass->addDeclCode(subst("// Normal delay $0 is of type $1", vname, nameDelayType(dt)));
-    string access = generateDelayLine(dt, ctype, vname, mxd, count, mono, exp, ccs);
-    setVectorNameProperty(sig, vname);
+    string access = generateDelayLine(dt, ctype, vecname, mxd, count, mono, exp, ccs);
+    // setVectorNameProperty(sig, vname);
     return access;
 #if 0
 #if OLDDELAY
@@ -1559,8 +1745,9 @@ string ScalarCompiler::generateDelayVecNoTemp(Tree sig, const string& exp, const
  * Generate code for the delay mechanism without using temporary variables
  */
 
-string ScalarCompiler::generateDelayLine(DelayType dt, const string& ctype, const string& vname, int mxd, int count,
-                                         bool mono, const string& exp, const string& ccs)
+string ScalarCompiler::generateDelayLine(DelayType dt, const string& ctype, const string& vname,
+                                         int mxd, int count, bool mono, const string& exp,
+                                         const string& ccs)
 {
 #if OLDDELAY
     if (mxd == 0) {
@@ -1602,19 +1789,21 @@ string ScalarCompiler::generateDelayLine(DelayType dt, const string& ctype, cons
 
         // execute
         std::string idx = subst("IOTA&$0", T(N - 1));
-        fClass->addExecCode(Statement(ccs, subst("$0[$1] = $2;", vname, generateIotaCache(idx), exp)));
+        fClass->addExecCode(
+            Statement(ccs, subst("$0[$1] = $2;", vname, generateIotaCache(idx), exp)));
     }
 #else
     switch (dt) {
         case DelayType::kNotADelay:
             faustexception("Try to compile has a delay something that is not a delay");
             return "";
-     
+
         case DelayType::kZeroDelay:
             // cerr << "MXD==0 :  " << vname << " := " << exp << endl;
             // no need for a real vector
             if (ccs == "") {
-                fClass->addExecCode(Statement(ccs, subst("$0 \t$1 = $2; // Zero delay", ctype, vname, exp)));
+                fClass->addExecCode(
+                    Statement(ccs, subst("$0 \t$1 = $2; // Zero delay", ctype, vname, exp)));
             } else {
                 fClass->addZone2(subst("$0 \t$1 = 0;", ctype, vname));
                 fClass->addExecCode(Statement(ccs, subst("\t$0 = $1;", vname, exp)));
@@ -1642,27 +1831,38 @@ string ScalarCompiler::generateDelayLine(DelayType dt, const string& ctype, cons
 
         case DelayType::kCopyDelay:
             fClass->addDeclCode(subst("$0 \t$1State[$2]; // Copy Delay", ctype, vname, T(mxd)));
-            fClass->addClearCode(subst("for (int j = 0; j < $0; j++) { $1State[j] = 0; }", T(mxd), vname));
+            fClass->addClearCode(
+                subst("for (int j = 0; j < $0; j++) { $1State[j] = 0; }", T(mxd), vname));
             fClass->addZone2(subst("$0 \t$1[$2];", ctype, vname, T(mxd + 1)));
-            for (int j = 0; j < mxd; j++) fClass->addZone3(subst("$0[$1] = $0State[$2];", vname, T(j + 1), T(j)));
+            for (int j = 0; j < mxd; j++) {
+                fClass->addZone3(subst("$0[$1] = $0State[$2];", vname, T(j + 1), T(j)));
+            }
             fClass->addExecCode(Statement(ccs, subst("$0[0] = $1;", vname, exp)));
             for (int j = 0; j < mxd; j++) {
                 // warning ; line stacked in reverse order !!!
-                fClass->addPostCode(Statement("", subst("$0[$1] = $0[$2];", vname, T(j + 1), T(j))));
+                fClass->addPostCode(
+                    Statement("", subst("$0[$1] = $0[$2];", vname, T(j + 1), T(j))));
+            }
+            for (int j = 0; j < mxd; j++) {
+                fClass->addZone3Post(subst("$0State[$1] = $0[$2];", vname, T(j), T(j + 1)));
             }
-            for (int j = 0; j < mxd; j++) fClass->addZone3Post(subst("$0State[$1] = $0[$2];", vname, T(j), T(j + 1)));
             return subst("$0[0]", vname);
 
         case DelayType::kDenseDelay:
 
             fClass->addDeclCode(subst("$0 \t$1State[$2]; // Dense Delay", ctype, vname, T(mxd)));
-            fClass->addClearCode(subst("for (int j = 0; j < $0; j++) { $1State[j] = 0; }", T(mxd), vname));
-            fClass->addZone2(subst("$0 \t$1Cache[$2+$3];", ctype, vname, T(gGlobal->gVecSize), T(mxd)));
-            fClass->addZone3(subst("$0* \t$1 = $1Cache + $2 - 1;", ctype, vname, T(gGlobal->gVecSize)));
-            fClass->addZone3(subst("for (int j = 0; j < $0; j++) { $1[j+1] = $1State[j]; }", T(mxd), vname));
+            fClass->addClearCode(
+                subst("for (int j = 0; j < $0; j++) { $1State[j] = 0; }", T(mxd), vname));
+            fClass->addZone2(
+                subst("$0 \t$1Cache[$2+$3];", ctype, vname, T(gGlobal->gVecSize), T(mxd)));
+            fClass->addZone3(
+                subst("$0* \t$1 = $1Cache + $2 - 1;", ctype, vname, T(gGlobal->gVecSize)));
+            fClass->addZone3(
+                subst("for (int j = 0; j < $0; j++) { $1[j+1] = $1State[j]; }", T(mxd), vname));
             fClass->addExecCode(Statement(ccs, subst("$0[0] = $1;", vname, exp)));
             fClass->addPostCode(Statement("", subst("--$0;", vname)));
-            fClass->addZone3Post(subst("for (int j = 0; j < $0; j++) { $1State[j] = $1[j+1]; }", T(mxd), vname));
+            fClass->addZone3Post(
+                subst("for (int j = 0; j < $0; j++) { $1State[j] = $1[j+1]; }", T(mxd), vname));
             return subst("$0[0]", vname);
 
         case DelayType::kMaskRingDelay:
@@ -1733,7 +1933,8 @@ void ScalarCompiler::declareWaveform(Tree sig, string& vname, int& size)
     fClass->addDeclCode(subst("int \tidx$0;", vname));
     fClass->addInitCode(subst("idx$0 = 0;", vname));
     fClass->getTopParentKlass()->addStaticFields(
-        subst("$0 \t$1::$2[$3] = ", ctype, fClass->getFullClassName(), vname, T(size)) + content.str() + ";");
+        subst("$0 \t$1::$2[$3] = ", ctype, fClass->getFullClassName(), vname, T(size)) +
+        content.str() + ";");
 }
 
 string ScalarCompiler::generateWaveform(Tree sig)
@@ -1742,6 +1943,7 @@ string ScalarCompiler::generateWaveform(Tree sig)
     int    size;
 
     declareWaveform(sig, vname, size);
-    fClass->addPostCode(Statement(getConditionCode(sig), subst("idx$0 = (idx$0 + 1) % $1;", vname, T(size))));
+    fClass->addPostCode(
+        Statement(getConditionCode(sig), subst("idx$0 = (idx$0 + 1) % $1;", vname, T(size))));
     return generateCacheCode(sig, subst("$0[idx$0]", vname));
 }
