@@ -19,8 +19,8 @@
  ************************************************************************
  ************************************************************************/
 
-#include <vector>
 #include "ppsig.hh"
+#include <vector>
 #include "Text.hh"
 #include "binop.hh"
 #include "exception.hh"
@@ -31,16 +31,24 @@
 
 using namespace std;
 
-ppsig::ppsig(Tree s, int max_size) : fSig(s), fEnv(gGlobal->nil),
-    fPriority(0), fHideRecursion(false), fMaxSize(max_size)
-{}
+ppsig::ppsig(Tree s, int max_size)
+    : fSig(s), fEnv(gGlobal->nil), fPriority(0), fHideRecursion(false), fMaxSize(max_size)
+{
+}
 
 ostream& ppsig::printinfix(ostream& fout, const string& opname, int priority, Tree x, Tree y) const
 {
-    if (fPriority > priority) fout << "(";
+#if 0
+    if (fPriority > priority) {
+        fout << "(";
+    }
     fout << ppsig(x, fEnv, priority, fMaxSize) << opname << ppsig(y, fEnv, priority, fMaxSize);
-    if (fPriority > priority) fout << ")";
+    if (fPriority > priority) {
+        fout << ")";
+    }
     return fout;
+#endif
+    return printfun(fout, opname, x, y);
 }
 
 ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x) const
@@ -50,23 +58,28 @@ ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x) const
 
 ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x, Tree y) const
 {
-    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ',' << ppsig(y, fEnv, 0, fMaxSize) << ')';
+    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ','
+                << ppsig(y, fEnv, 0, fMaxSize) << ')';
 }
 
 ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z) const
 {
-    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ',' << ppsig(y, fEnv, 0, fMaxSize) << ',' << ppsig(z, fEnv, 0, fMaxSize) << ')';
+    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ','
+                << ppsig(y, fEnv, 0, fMaxSize) << ',' << ppsig(z, fEnv, 0, fMaxSize) << ')';
 }
 
 ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z, Tree zz) const
 {
-    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ',' << ppsig(y, fEnv, 0, fMaxSize) << ',' << ppsig(z, fEnv, 0, fMaxSize) << ','
+    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ','
+                << ppsig(y, fEnv, 0, fMaxSize) << ',' << ppsig(z, fEnv, 0, fMaxSize) << ','
                 << ppsig(zz, fEnv, 0, fMaxSize) << ')';
 }
 
-ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z, Tree z2, Tree z3) const
+ostream& ppsig::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z, Tree z2,
+                         Tree z3) const
 {
-    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ',' << ppsig(y, fEnv, 0, fMaxSize) << ',' << ppsig(z, fEnv, 0, fMaxSize) << ','
+    return fout << funame << '(' << ppsig(x, fEnv, 0, fMaxSize) << ','
+                << ppsig(y, fEnv, 0, fMaxSize) << ',' << ppsig(z, fEnv, 0, fMaxSize) << ','
                 << ppsig(z2, fEnv, 0, fMaxSize) << ',' << ppsig(z3, fEnv, 0, fMaxSize) << ')';
 }
 
@@ -77,26 +90,34 @@ ostream& ppsig::printui(ostream& fout, const string& funame, Tree label) const
     return fout << ')';
 }
 
-ostream& ppsig::printui(ostream& fout, const string& funame, Tree label, Tree lo, Tree hi, Tree step) const
+ostream& ppsig::printui(ostream& fout, const string& funame, Tree label, Tree lo, Tree hi,
+                        Tree step) const
 {
     fout << funame << '(';
     printlabel(fout, label);
-    return fout << ',' << ppsig(lo, fEnv, 0, fMaxSize) << ',' << ppsig(hi, fEnv, 0, fMaxSize) << ',' << ppsig(step, fEnv, 0, fMaxSize) << ')';
+    return fout << ',' << ppsig(lo, fEnv, 0, fMaxSize) << ',' << ppsig(hi, fEnv, 0, fMaxSize) << ','
+                << ppsig(step, fEnv, 0, fMaxSize) << ')';
 }
 
-ostream& ppsig::printui(ostream& fout, const string& funame, Tree label, Tree cur, Tree lo, Tree hi, Tree step) const
+ostream& ppsig::printui(ostream& fout, const string& funame, Tree label, Tree cur, Tree lo, Tree hi,
+                        Tree step) const
 {
     fout << funame << '(';
     printlabel(fout, label);
-    return fout << ',' << ppsig(cur, fEnv, 0, fMaxSize) << ',' << ppsig(lo, fEnv, 0, fMaxSize) << ',' << ppsig(hi, fEnv, 0, fMaxSize) << ','
-                << ppsig(step, fEnv, 0, fMaxSize) << ')';
+    return fout << ',' << ppsig(cur, fEnv, 0, fMaxSize) << ',' << ppsig(lo, fEnv, 0, fMaxSize)
+                << ',' << ppsig(hi, fEnv, 0, fMaxSize) << ',' << ppsig(step, fEnv, 0, fMaxSize)
+                << ')';
 }
 
 ostream& ppsig::printout(ostream& fout, int i, Tree x) const
 {
-    if (fPriority > 0) fout << "(";
+    if (fPriority > 0) {
+        fout << "(";
+    }
     fout << "OUT" << i << " = " << ppsig(x, fEnv, 0, fMaxSize);
-    if (fPriority > 0) fout << ")";
+    if (fPriority > 0) {
+        fout << ")";
+    }
     return fout;
 }
 
@@ -134,13 +155,14 @@ ostream& ppsig::printff(ostream& fout, Tree ff, Tree largs) const
 
 ostream& ppsig::printDelay(ostream& fout, Tree exp, Tree delay) const
 {
-    int d;
+    // int d;
 
-    if (isSigInt(delay, &d) && (d == 1)) {
-        fout << ppsig(exp, fEnv, 8, fMaxSize) << "'";
-    } else {
-        printinfix(fout, "@", 8, exp, delay);
-    }
+    // if (isSigInt(delay, &d) && (d == 1)) {
+    //     fout << ppsig(exp, fEnv, 8, fMaxSize) << "'";
+    // } else {
+    //     printinfix(fout, "@", 8, exp, delay);
+    // }
+    printfun(fout, "Delay", exp, delay);
     return fout;
 }
 
@@ -191,8 +213,11 @@ ostream& ppsig::printextended(ostream& fout, Tree sig1) const
 ostream& ppsig::print(ostream& fout) const
 {
     // Stops printing at fMaxSize characters
-    if (fout.tellp() > fMaxSize) { fout << "..."; return fout; }
-    
+    if (fout.tellp() > fMaxSize) {
+        fout << "...";
+        return fout;
+    }
+
     int    i;
     double r;
     Tree   c, sel, w, x, y, z, u, var, le, label, ff, largs, type, name, file, sf;
@@ -227,9 +252,8 @@ ostream& ppsig::print(ostream& fout) const
     }
 
     else if (isSigDelay1(fSig, x)) {
-        fout << ppsig(x, fEnv, 9, fMaxSize) << "'";
-    }
-    else if (isSigDelay(fSig, x, y)) {
+        printDelay(fout, x, sigInt(1));
+    } else if (isSigDelay(fSig, x, y)) {
         printDelay(fout, x, y);
     } else if (isSigPrefix(fSig, x, y)) {
         printfun(fout, "prefix", x, y);
@@ -245,18 +269,19 @@ ostream& ppsig::print(ostream& fout) const
 
     if (isSigWRTbl(fSig, w, x, y, z)) {
         if (y == gGlobal->nil) {
-            // rdtable
-            printfun(fout, "TABLE", w, x);
+            // readonly table
+            printfun(fout, "WRTbl2p", w, x);
         } else {
             // rwtable
-            printfun(fout, "write(TABLE", w, x);
-            fout << "," << ppsig(y, fEnv, 0, fMaxSize);
-            fout << "," << ppsig(z, fEnv, 0, fMaxSize) << ")";
+            fout << "sigWRTbl4p(" << ppsig(w, fEnv, 0, fMaxSize);
+            fout << "; " << ppsig(x, fEnv, 0, fMaxSize);
+            fout << "; " << ppsig(y, fEnv, 0, fMaxSize);
+            fout << "; " << ppsig(z, fEnv, 0, fMaxSize) << " )";
         }
     } else if (isSigRDTbl(fSig, x, y)) {
-        printfun(fout, "read", x, y);
+        printfun(fout, "sigRDTbl", x, y);
     } else if (isSigGen(fSig, x)) {
-        fout << ppsig(x, fEnv, fPriority, fMaxSize);
+        fout << "sigGen(" << ppsig(x, fEnv, fPriority, fMaxSize) << ")";
     }
 
     else if (isSigDocConstantTbl(fSig, x, y)) {
@@ -313,27 +338,37 @@ ostream& ppsig::print(ostream& fout) const
         printfun(fout, "control", x, y);
     }
 
+    else if (isSigRegister(fSig, &i, x)) {
+        printfun(fout, "register", sigInt(i), x);
+    }
+
     else {
         // cerr << "[[" << *fSig << "]]";
     }
     return fout;
 }
 
-#define SIG_INSERT_ID(exp) \
-    if (gGlobal->gSignalTable.find(fSig) == gGlobal->gSignalTable.end()) { \
-        stringstream s; \
-        (exp); \
-        gGlobal->gSignalTable[fSig] = make_pair(gGlobal->gSignalCounter, s.str()); \
-        gGlobal->gSignalTrace.push_back("ID_" + std::to_string(gGlobal->gSignalCounter) + " = " + s.str() + ";\n"); \
-        gGlobal->gSignalCounter++;\
-    } \
-    fout << "ID_" << gGlobal->gSignalTable[fSig].first; \
+#define SIG_INSERT_ID(exp)                                                                        \
+    if (gGlobal->gSignalTable.find(fSig) == gGlobal->gSignalTable.end()) {                        \
+        stringstream s;                                                                           \
+        (exp);                                                                                    \
+        gGlobal->gSignalTable[fSig] = make_pair(gGlobal->gSignalCounter, s.str());                \
+        gGlobal->gSignalTrace.push_back("ID_" + std::to_string(gGlobal->gSignalCounter) + " = " + \
+                                        s.str() + ";\n");                                         \
+        gGlobal->gSignalCounter++;                                                                \
+    }                                                                                             \
+    fout << "ID_" << gGlobal->gSignalTable[fSig].first;
 
-ostream& ppsigShared::printinfix(ostream& fout, const string& opname, int priority, Tree x, Tree y) const
+ostream& ppsigShared::printinfix(ostream& fout, const string& opname, int priority, Tree x,
+                                 Tree y) const
 {
-    if (fPriority > priority) fout << "(";
+    if (fPriority > priority) {
+        fout << "(";
+    }
     fout << ppsigShared(x, fEnv, priority) << opname << ppsigShared(y, fEnv, priority);
-    if (fPriority > priority) fout << ")";
+    if (fPriority > priority) {
+        fout << ")";
+    }
     return fout;
 }
 
@@ -349,19 +384,23 @@ ostream& ppsigShared::printfun(ostream& fout, const string& funame, Tree x, Tree
 
 ostream& ppsigShared::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z) const
 {
-    return fout << funame << '(' << ppsigShared(x, fEnv) << ',' << ppsigShared(y, fEnv) << ',' << ppsigShared(z, fEnv) << ')';
+    return fout << funame << '(' << ppsigShared(x, fEnv) << ',' << ppsigShared(y, fEnv) << ','
+                << ppsigShared(z, fEnv) << ')';
 }
 
-ostream& ppsigShared::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z, Tree zz) const
+ostream& ppsigShared::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z,
+                               Tree zz) const
 {
-    return fout << funame << '(' << ppsigShared(x, fEnv) << ',' << ppsigShared(y, fEnv) << ',' << ppsigShared(z, fEnv) << ','
-    << ppsigShared(zz, fEnv) << ')';
+    return fout << funame << '(' << ppsigShared(x, fEnv) << ',' << ppsigShared(y, fEnv) << ','
+                << ppsigShared(z, fEnv) << ',' << ppsigShared(zz, fEnv) << ')';
 }
 
-ostream& ppsigShared::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z, Tree z2, Tree z3) const
+ostream& ppsigShared::printfun(ostream& fout, const string& funame, Tree x, Tree y, Tree z, Tree z2,
+                               Tree z3) const
 {
-    return fout << funame << '(' << ppsigShared(x, fEnv) << ',' << ppsigShared(y, fEnv) << ',' << ppsigShared(z, fEnv) << ','
-    << ppsigShared(z2, fEnv) << ',' << ppsigShared(z3, fEnv) << ')';
+    return fout << funame << '(' << ppsigShared(x, fEnv) << ',' << ppsigShared(y, fEnv) << ','
+                << ppsigShared(z, fEnv) << ',' << ppsigShared(z2, fEnv) << ','
+                << ppsigShared(z3, fEnv) << ')';
 }
 
 ostream& ppsigShared::printui(ostream& fout, const string& funame, Tree label) const
@@ -371,26 +410,33 @@ ostream& ppsigShared::printui(ostream& fout, const string& funame, Tree label) c
     return fout << ')';
 }
 
-ostream& ppsigShared::printui(ostream& fout, const string& funame, Tree label, Tree lo, Tree hi, Tree step) const
+ostream& ppsigShared::printui(ostream& fout, const string& funame, Tree label, Tree lo, Tree hi,
+                              Tree step) const
 {
     fout << funame << '(';
     printlabel(fout, label);
-    return fout << ',' << ppsigShared(lo, fEnv) << ',' << ppsigShared(hi, fEnv) << ',' << ppsigShared(step, fEnv) << ')';
+    return fout << ',' << ppsigShared(lo, fEnv) << ',' << ppsigShared(hi, fEnv) << ','
+                << ppsigShared(step, fEnv) << ')';
 }
 
-ostream& ppsigShared::printui(ostream& fout, const string& funame, Tree label, Tree cur, Tree lo, Tree hi, Tree step) const
+ostream& ppsigShared::printui(ostream& fout, const string& funame, Tree label, Tree cur, Tree lo,
+                              Tree hi, Tree step) const
 {
     fout << funame << '(';
     printlabel(fout, label);
-    return fout << ',' << ppsigShared(cur, fEnv) << ',' << ppsigShared(lo, fEnv) << ',' << ppsigShared(hi, fEnv) << ','
-    << ppsigShared(step, fEnv) << ')';
+    return fout << ',' << ppsigShared(cur, fEnv) << ',' << ppsigShared(lo, fEnv) << ','
+                << ppsigShared(hi, fEnv) << ',' << ppsigShared(step, fEnv) << ')';
 }
 
 ostream& ppsigShared::printout(ostream& fout, int i, Tree x) const
 {
-    if (fPriority > 0) fout << "(";
+    if (fPriority > 0) {
+        fout << "(";
+    }
     fout << "OUT" << i << " = " << ppsigShared(x, fEnv, 0);
-    if (fPriority > 0) fout << ")";
+    if (fPriority > 0) {
+        fout << ")";
+    }
     return fout;
 }
 
@@ -417,7 +463,7 @@ ostream& ppsigShared::printff(ostream& fout, Tree ff, Tree largs) const
 ostream& ppsigShared::printDelay(ostream& fout, Tree exp, Tree delay) const
 {
     int d;
-    
+
     if (isSigInt(delay, &d) && (d == 1)) {
         fout << ppsigShared(exp, fEnv, 8) << "'";
     } else {
@@ -448,7 +494,7 @@ ostream& ppsigShared::printextended(ostream& fout, Tree sig1) const
 {
     string   sep = "";
     xtended* p   = (xtended*)getUserData(fSig);
-    
+
     fout << p->name() << '(';
     for (int i = 0; i < sig1->arity(); i++) {
         fout << sep << ppsigShared(sig1->branch(i), fEnv);
@@ -463,7 +509,7 @@ ostream& ppsigShared::print(ostream& fout) const
     int    i;
     double r;
     Tree   c, sel, w, x, y, z, u, var, le, label, ff, largs, type, name, file, sf;
-    
+
     if (isList(fSig)) {
         printlist(fout, fSig);
     } else if (isProj(fSig, &i, x)) {
@@ -471,14 +517,14 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isRec(fSig, var, le)) {
         SIG_INSERT_ID(printrec(s, var, le, fHideRecursion));
     }
-    
+
     // debruinj notation
     else if (isRec(fSig, le)) {
         SIG_INSERT_ID(printrec(s, le, fHideRecursion));
     } else if (isRef(fSig, i)) {
         fout << "REF[" << i << "]";
     }
-    
+
     else if (getUserData(fSig)) {
         SIG_INSERT_ID(printextended(s, fSig));
     } else if (isSigInt(fSig, &i)) {
@@ -492,11 +538,10 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigOutput(fSig, &i, x)) {
         SIG_INSERT_ID(printout(s, i, x));
     }
-    
+
     else if (isSigDelay1(fSig, x)) {
-        SIG_INSERT_ID(s << ppsigShared(x, fEnv, 9) << "'");
-    }
-    else if (isSigDelay(fSig, x, y)) {
+        SIG_INSERT_ID(printDelay(s, x, sigInt(1)));
+    } else if (isSigDelay(fSig, x, y)) {
         SIG_INSERT_ID(printDelay(s, x, y));
     } else if (isSigPrefix(fSig, x, y)) {
         SIG_INSERT_ID(printfun(s, "prefix", x, y));
@@ -509,7 +554,7 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigFVar(fSig, type, name, file)) {
         fout << tree2str(name);
     }
-    
+
     if (isSigWRTbl(fSig, w, x, y, z)) {
         SIG_INSERT_ID(printfun(s, "write", w, x, y, z));
     } else if (isSigRDTbl(fSig, x, y)) {
@@ -517,7 +562,7 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigGen(fSig, x)) {
         SIG_INSERT_ID(s << ppsigShared(x, fEnv, fPriority));
     }
-    
+
     else if (isSigDocConstantTbl(fSig, x, y)) {
         SIG_INSERT_ID(printfun(s, "docConstantTbl", x, y));
     } else if (isSigDocWriteTbl(fSig, x, y, z, u)) {
@@ -525,11 +570,11 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigDocAccessTbl(fSig, x, y)) {
         SIG_INSERT_ID(printfun(fout, "docAccessTbl", x, y));
     }
-    
+
     else if (isSigSelect2(fSig, sel, x, y)) {
         SIG_INSERT_ID(printfun(s, "select2", sel, x, y));
     }
-    
+
     else if (isSigIntCast(fSig, x)) {
         SIG_INSERT_ID(printfun(s, "int", x));
     } else if (isSigBitCast(fSig, x)) {
@@ -537,7 +582,7 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigFloatCast(fSig, x)) {
         SIG_INSERT_ID(printfun(s, "float", x));
     }
-    
+
     else if (isSigButton(fSig, label)) {
         SIG_INSERT_ID(printui(s, "button", label));
     } else if (isSigCheckbox(fSig, label)) {
@@ -553,7 +598,7 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigHBargraph(fSig, label, x, y, z)) {
         SIG_INSERT_ID(printui(s, "hbargraph", label, x, y, z));
     }
-    
+
     else if (isSigSoundfile(fSig, label)) {
         SIG_INSERT_ID(printui(s, "soundfile", label));
     } else if (isSigSoundfileLength(fSig, sf, x)) {
@@ -563,7 +608,7 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigSoundfileBuffer(fSig, sf, x, y, z)) {
         SIG_INSERT_ID(printfun(s, "buffer", sf, x, y, z));
     }
-    
+
     else if (isSigAttach(fSig, x, y)) {
         SIG_INSERT_ID(printfun(s, "attach", x, y));
     } else if (isSigEnable(fSig, x, y)) {
@@ -571,7 +616,11 @@ ostream& ppsigShared::print(ostream& fout) const
     } else if (isSigControl(fSig, x, y)) {
         SIG_INSERT_ID(printfun(s, "control", x, y));
     }
-    
+
+    else if (isSigRegister(fSig, &i, x)) {
+        SIG_INSERT_ID(printfun(s, "register", sigInt(i), x));
+    }
+
     else {
         // cerr << "[[" << *fSig << "]]";
     }
@@ -585,7 +634,9 @@ void ppsigShared::printIDs(ostream& fout, bool sort)
      we sort the list to be sure it stays the same.
      To be removed if the tree shape becomes deterministic.
      */
-    if (sort) std::sort(gGlobal->gSignalTrace.begin(), gGlobal->gSignalTrace.end());
+    if (sort) {
+        std::sort(gGlobal->gSignalTrace.begin(), gGlobal->gSignalTrace.end());
+    }
     fout << "// Size = " << gGlobal->gSignalTrace.size() << endl;
     for (const auto& it : gGlobal->gSignalTrace) {
         fout << it;
