@@ -27,6 +27,7 @@
 
 #include "exception.hh"
 #include "global.hh"
+#include "interval_def.hh"
 #include "ppsig.hh"
 #include "prim2.hh"
 #include "recursivness.hh"
@@ -151,10 +152,10 @@ static interval arithmetic(int opcode, const interval& x, const interval& y)
         default:
             cerr << "ASSERT : unrecognized opcode : " << opcode << endl;
             faustassert(false);
-            return {};
+            return itv::empty();
     }
 
-    return interval();
+    return itv::empty();
 }
 
 // Uncomment to activate type inferrence tracing
@@ -171,24 +172,25 @@ static interval arithmetic(int opcode, const interval& x, const interval& y)
 
 /**
  * Do one step of type inference on the recursive signal groups of a signal
- * The types of the recursive signals are updated to vtype and then vtype is updated to the next step.
+ * The types of the recursive signals are updated to vtype and then vtype is updated to the next
+ * step.
  *
  * @param vrec array of all the recursive signal groups
  * @param vdef definitions of all the recursive signal groups (vector of _lists_)
  * @param vdefSizes number of signals in each recursive signal groups
  * @param vtype types of the recursive signals
- * @param inter if set to false, the interval of the new type is the union of the old one and the computed one,
- * otherwise it is the intersection
+ * @param inter if set to false, the interval of the new type is the union of the old one and the
+ * computed one, otherwise it is the intersection
  */
-static void updateRecTypes(vector<Tree>& vrec, const vector<Tree>& vdef, const vector<int>& vdefSizes,
-                           vector<Type>& vtype, const bool inter)
+static void updateRecTypes(vector<Tree>& vrec, const vector<Tree>& vdef,
+                           const vector<int>& vdefSizes, vector<Type>& vtype, const bool inter)
 {
     Type         newType;
     vector<Type> newTuplet;
     TupletType   newRecType;
     TupletType   oldRecType;
-    interval     newI;
-    interval     oldI;
+    interval     newI(NAN, NAN);
+    interval     oldI(NAN, NAN);
 
     const int n = vdef.size();
 
@@ -233,12 +235,12 @@ void typeAnnotation(Tree sig, bool causality)
     int  size;
     bool finished = false;
 
-    vector<Tree>       vrec;       ///< array of all the recursive signal groups
-    vector<Tree>       vdef;       ///< definitions of all the recursive signal groups (vector of _lists_)
-    vector<int>        vdefSizes;  ///< number of signals for each group
-    vector<Type>       vtype;      ///< type of the recursive signals
-    vector<Type>       vtypeUp;    ///< an upperbound of the recursive signals type
-    vector<TupletType> vUp;        ///< the unfolded version of the variable above
+    vector<Tree> vrec;       ///< array of all the recursive signal groups
+    vector<Tree> vdef;       ///< definitions of all the recursive signal groups (vector of _lists_)
+    vector<int>  vdefSizes;  ///< number of signals for each group
+    vector<Type> vtype;      ///< type of the recursive signals
+    vector<Type> vtypeUp;    ///< an upperbound of the recursive signals type
+    vector<TupletType> vUp;  ///< the unfolded version of the variable above
 
     vector<vector<int>> vAgeMin;  ///< age of the minimum of every subsignal of the recursive signal
     vector<vector<int>> vAgeMax;  ///< age of the maximum of every subsignal of the recursive signal
@@ -247,8 +249,8 @@ void typeAnnotation(Tree sig, bool causality)
     vector<Type> newTuplet;
     TupletType   newRecType;
     TupletType   oldRecType;
-    interval     newI;
-    interval     oldI;
+    interval     newI(NAN, NAN);
+    interval     oldI(NAN, NAN);
 
     // cerr << "Symlist " << *sl << endl;
     for (Tree l = sl; isList(l); l = tl(l)) {
@@ -295,7 +297,8 @@ void typeAnnotation(Tree sig, bool causality)
         finished = true;
         for (int i = 0; i < n; i++) {
             newTuplet.clear();
-            //cerr << i << "-" << *vrec[i] << ":" << *getSigType(vrec[i]) << " => " << *vtype[i] << endl;
+            // cerr << i << "-" << *vrec[i] << ":" << *getSigType(vrec[i]) << " => " << *vtype[i] <<
+            // endl;
             if (vtype[i] != getSigType(vrec[i])) {
                 finished   = false;
                 newRecType = derefRecCert(vtype[i]);
@@ -310,7 +313,8 @@ void typeAnnotation(Tree sig, bool causality)
                         faustassert(newI.lo() < oldI.lo());
                         vAgeMin[i][j]++;
                         if (vAgeMin[i][j] > gGlobal->gWideningLimit) {
-                            TRACE(cerr << gGlobal->TABBER << "low widening of " << newTuplet[j] << endl;)
+                            TRACE(cerr << gGlobal->TABBER << "low widening of " << newTuplet[j]
+                                       << endl;)
                             newI = {vUp[i][j]->getInterval().lo(), newI.hi()};
                         }
                     }
@@ -319,7 +323,8 @@ void typeAnnotation(Tree sig, bool causality)
                         faustassert(newI.hi() > oldI.hi());
                         vAgeMax[i][j]++;
                         if (vAgeMax[i][j] > gGlobal->gWideningLimit) {
-                            TRACE(cerr << gGlobal->TABBER << "up widening of " << newTuplet[j] << endl;)
+                            TRACE(cerr << gGlobal->TABBER << "up widening of " << newTuplet[j]
+                                       << endl;)
                             newI = {newI.lo(), vUp[i][j]->getInterval().hi()};
                         }
                     }
@@ -373,7 +378,8 @@ static void annotationStatistics()
  */
 void setSigType(Tree sig, Type t)
 {
-    TRACE(cerr << gGlobal->TABBER << "SET FIX TYPE OF " << ppsig(sig, MAX_ERROR_SIZE) << " TO TYPE " << *t << endl;)
+    TRACE(cerr << gGlobal->TABBER << "SET FIX TYPE OF " << ppsig(sig, MAX_ERROR_SIZE) << " TO TYPE "
+               << *t << endl;)
     sig->setType(t);
 }
 
@@ -385,11 +391,11 @@ Type getSigType(Tree sig)
 {
     AudioType* ty = (AudioType*)sig->getType();
     if (ty == nullptr) {
-        TRACE(cerr << gGlobal->TABBER << "GET FIX TYPE OF " << ppsig(sig, MAX_ERROR_SIZE) << " HAS NO TYPE YET"
-                   << endl;)
+        TRACE(cerr << gGlobal->TABBER << "GET FIX TYPE OF " << ppsig(sig, MAX_ERROR_SIZE)
+                   << " HAS NO TYPE YET" << endl;)
     } else {
-        TRACE(cerr << gGlobal->TABBER << "GET FIX TYPE OF " << ppsig(sig, MAX_ERROR_SIZE) << " IS TYPE " << *ty
-                   << endl;)
+        TRACE(cerr << gGlobal->TABBER << "GET FIX TYPE OF " << ppsig(sig, MAX_ERROR_SIZE)
+                   << " IS TYPE " << *ty << endl;)
     }
     return ty;
 }
@@ -407,7 +413,8 @@ Type getSigType(Tree sig)
 ***************************************************************************/
 
 /**
- * Shortcut to getOrInferType, retrieve or infer the type of a term according to its surrounding type environment
+ * Shortcut to getOrInferType, retrieve or infer the type of a term according to its surrounding
+ * type environment
  * @param sig the signal to analyze
  * @param env the type environment
  * @return the type of sig according to environment env
@@ -419,14 +426,16 @@ static Type T(Tree term, Tree ignoreenv)
 
     if (term->isAlreadyVisited()) {
         Type ty = getSigType(term);
-        TRACE(cerr << --gGlobal->TABBER << "EXIT 1 T() " << ppsig(term, MAX_ERROR_SIZE) << " AS TYPE " << *ty << endl);
+        TRACE(cerr << --gGlobal->TABBER << "EXIT 1 T() " << ppsig(term, MAX_ERROR_SIZE)
+                   << " AS TYPE " << *ty << endl);
         return ty;
 
     } else {
         Type ty = inferSigType(term, ignoreenv);
         setSigType(term, ty);
         term->setVisited();
-        TRACE(cerr << --gGlobal->TABBER << "EXIT 2 T() " << ppsig(term, MAX_ERROR_SIZE) << " AS TYPE " << *ty << endl);
+        TRACE(cerr << --gGlobal->TABBER << "EXIT 2 T() " << ppsig(term, MAX_ERROR_SIZE)
+                   << " AS TYPE " << *ty << endl);
         return ty;
     }
 }
@@ -437,7 +446,8 @@ static void checkPartInterval(Tree s, Type t)
     if (!i.isValid() || (i.lo() < 0) || (i.hi() >= MAX_SOUNDFILE_PARTS)) {
         stringstream error;
         error << "ERROR : out of range soundfile part number (" << i << " instead of interval(0,"
-              << MAX_SOUNDFILE_PARTS - 1 << ")) in expression : " << ppsig(s, MAX_ERROR_SIZE) << endl;
+              << MAX_SOUNDFILE_PARTS - 1 << ")) in expression : " << ppsig(s, MAX_ERROR_SIZE)
+              << endl;
         throw faustexception(error.str());
     }
 }
@@ -458,8 +468,9 @@ static Type inferSigType(Tree sig, Tree env)
 
     gGlobal->gCountInferences++;
 
-    if (getUserData(sig))
+    if (getUserData(sig)) {
         return inferXType(sig, env);
+    }
 
     else if (isSigInt(sig, &i)) {
         Type t = makeSimpleType(kInt, kKonst, kComp, kVect, kNum, gAlgebra.IntNum(i));
@@ -467,7 +478,7 @@ static Type inferSigType(Tree sig, Tree env)
     }
 
     else if (isSigInt64(sig, &i64)) {
-        Type t = makeSimpleType(kInt, kKonst, kComp, kVect, kNum, gAlgebra.IntNum(i));
+        Type t = makeSimpleType(kInt, kKonst, kComp, kVect, kNum, gAlgebra.Int64Num(i));
         return t;
     }
 
@@ -484,8 +495,9 @@ static Type inferSigType(Tree sig, Tree env)
         return gGlobal->TINPUT;
     }
 
-    else if (isSigOutput(sig, &i, s1))
+    else if (isSigOutput(sig, &i, s1)) {
         return sampCast(T(s1, env));
+    }
 
     else if (isSigDelay1(sig, s1)) {
         Type t = T(s1, env);
@@ -504,20 +516,26 @@ static Type inferSigType(Tree sig, Tree env)
         Type     t2 = T(s2, env);
         interval i1 = t2->getInterval();
 
-        //        cerr << "for sig fix delay : s1 = "
-        //        << t1 << ':' << ppsig(s1) << ", s2 = "
-        //        << t2 << ':' << ppsig(s2) << endl;
+        // cerr << "for sig fix delay : s1 = "
+        //      << t1 << ':' << ppsig(s1) << ", s2 = "
+        //      << t2 << ':' << ppsig(s2) << endl;
         if (gGlobal->gCausality) {
             if (!(i1.isValid()) || !(i1.isBounded())) {
-                stringstream error;
-                error << "ERROR : can't compute the min and max values of : " << ppsig(s2, MAX_ERROR_SIZE) << endl
-                      << "        used in delay expression : " << ppsig(sig, MAX_ERROR_SIZE) << endl
+                stringstream error, st1, st2;
+                // Prepare two separated streams for MAX_ERROR_SIZE model to work properly
+                st1 << ppsig(s1, MAX_ERROR_SIZE);
+                st2 << ppsig(s2, MAX_ERROR_SIZE);
+                error << "ERROR : can't compute the min and max values of : " << st2.str() << endl
+                      << "        used in delay expression : " << st1.str() << endl
                       << "        (probably a recursive signal)" << endl;
                 throw faustexception(error.str());
             } else if (i1.lo() < 0) {
-                stringstream error;
-                error << "ERROR : possible negative values of : " << ppsig(s2, MAX_ERROR_SIZE) << endl
-                      << "        used in delay expression : " << ppsig(sig, MAX_ERROR_SIZE) << endl
+                stringstream error, st1, st2;
+                // Prepare two separated streams for MAX_ERROR_SIZE model to work properly
+                st1 << ppsig(s1, MAX_ERROR_SIZE);
+                st2 << ppsig(s2, MAX_ERROR_SIZE);
+                error << "ERROR : possible negative values of : " << st2.str() << endl
+                      << "        used in delay expression : " << st1.str() << endl
                       << "        " << i1 << endl;
                 throw faustexception(error.str());
             }
@@ -530,44 +548,50 @@ static Type inferSigType(Tree sig, Tree env)
         Type t1 = T(s1, env);
         Type t2 = T(s2, env);
         Type t3 = castInterval(t1 | t2, arithmetic(i, t1->getInterval(), t2->getInterval()));
-   
+
         if (i == kDiv) {
-            return floatCast(t3);   // division always result in a float even with int arguments
+            return floatCast(t3);  // division always result in a float even with int arguments
         } else if ((i >= kGT) && (i <= kNE)) {
-            return boolCast(t3);    // comparison always result in a boolean int
+            return boolCast(t3);  // comparison always result in a boolean int
         } else if (((i >= kLsh) && (i <= kLRsh)) || ((i >= kAND) && (i <= kXOR))) {
-            return intCast(t3);     // boolean and logical operators always result in an int
+            return intCast(t3);  // boolean and logical operators always result in an int
         } else {
             return t3;  //  otherwise most general of t1 and t2
         }
     }
 
-    else if (isSigIntCast(sig, s1))
+    else if (isSigIntCast(sig, s1)) {
         return intCast(T(s1, env));
+    }
 
-    else if (isSigBitCast(sig, s1))
+    else if (isSigBitCast(sig, s1)) {
         return bitCast(T(s1, env));
+    }
 
-    else if (isSigFloatCast(sig, s1))
+    else if (isSigFloatCast(sig, s1)) {
         return floatCast(T(s1, env));
+    }
 
-    else if (isSigFFun(sig, ff, ls))
+    else if (isSigFFun(sig, ff, ls)) {
         return inferFFType(ff, ls, env);
+    }
 
-    else if (isSigFConst(sig, type, name, file))
+    else if (isSigFConst(sig, type, name, file)) {
         return inferFConstType(type);
+    }
 
-    else if (isSigFVar(sig, type, name, file))
+    else if (isSigFVar(sig, type, name, file)) {
         return inferFVarType(type);
+    }
 
-    else if (isSigButton(sig)) { 
-        return castInterval(gGlobal->TGUI, 
-                            gAlgebra.Button(interval(0, 0))); // todo replace the name
+    else if (isSigButton(sig)) {
+        return castInterval(gGlobal->TGUI,
+                            gAlgebra.Button(interval(0, 0)));  // TODO: replace the name
     }
 
     else if (isSigCheckbox(sig)) {
         return castInterval(gGlobal->TGUI,
-                            gAlgebra.Checkbox(interval(0, 0))); // todo replace the name
+                            gAlgebra.Checkbox(interval(0, 0)));  // TODO: replace the name
     }
 
     else if (isSigVSlider(sig, label, cur, min, max, step)) {
@@ -575,12 +599,10 @@ static Type inferSigType(Tree sig, Tree env)
         Type t2 = T(min, env);
         Type t3 = T(max, env);
         Type t4 = T(step, env);
-        return castInterval(gGlobal->TGUI, 
-                            gAlgebra.VSlider(interval(0, 0), // todo replace the name
-                            t1->getInterval(), 
-                            t2->getInterval(),
-                            t3->getInterval(),
-                            t4->getInterval()));
+        return castInterval(
+            gGlobal->TGUI, gAlgebra.VSlider(interval(0, 0),  // TODO: replace the name
+                                            t1->getInterval(), t2->getInterval(), t3->getInterval(),
+                                            t4->getInterval()));
     }
 
     else if (isSigHSlider(sig, label, cur, min, max, step)) {
@@ -588,12 +610,10 @@ static Type inferSigType(Tree sig, Tree env)
         Type t2 = T(min, env);
         Type t3 = T(max, env);
         Type t4 = T(step, env);
-        return castInterval(gGlobal->TGUI, 
-                            gAlgebra.HSlider(interval(0, 0), // todo replace the name
-                            t1->getInterval(),
-                            t2->getInterval(),
-                            t3->getInterval(),
-                            t4->getInterval()));
+        return castInterval(
+            gGlobal->TGUI, gAlgebra.HSlider(interval(0, 0),  // TODO: replace the name
+                                            t1->getInterval(), t2->getInterval(), t3->getInterval(),
+                                            t4->getInterval()));
     }
 
     else if (isSigNumEntry(sig, label, cur, min, max, step)) {
@@ -601,12 +621,10 @@ static Type inferSigType(Tree sig, Tree env)
         Type t2 = T(min, env);
         Type t3 = T(max, env);
         Type t4 = T(step, env);
-        return castInterval(gGlobal->TGUI, 
-                            gAlgebra.NumEntry(interval(0, 0), // todo replace the name
-                            t1->getInterval(),
-                            t2->getInterval(),
-                            t3->getInterval(),
-                            t4->getInterval()));
+        return castInterval(gGlobal->TGUI,
+                            gAlgebra.NumEntry(interval(0, 0),  // TODO: replace the name
+                                              t1->getInterval(), t2->getInterval(),
+                                              t3->getInterval(), t4->getInterval()));
     }
 
     else if (isSigHBargraph(sig, l, x, y, s1)) {
@@ -665,11 +683,13 @@ static Type inferSigType(Tree sig, Tree env)
         return T(s1, env);
     }
 
-    else if (isRec(sig, var, body))
+    else if (isRec(sig, var, body)) {
         return inferRecType(sig, body, env);
+    }
 
-    else if (isProj(sig, &i, s1))
+    else if (isProj(sig, &i, s1)) {
         return inferProjType(T(s1, env), i, kScal);
+    }
 
     else if (isSigWRTbl(sig, s1, s2, s3, s4)) {
         if (s3 == gGlobal->nil) {
@@ -680,19 +700,22 @@ static Type inferSigType(Tree sig, Tree env)
             return inferWriteTableType(inferTableType(s1, s2, env), T(s3, env), T(s4, env));
         }
     }
-    
-    else if (isSigRDTbl(sig, s1, s2))
+
+    else if (isSigRDTbl(sig, s1, s2)) {
         return inferReadTableType(T(s1, env), T(s2, env));
+    }
 
-    else if (isSigGen(sig, s1))
+    else if (isSigGen(sig, s1)) {
         return T(s1, gGlobal->NULLTYPEENV);
+    }
 
-    else if (isSigDocConstantTbl(sig, x, y))
+    else if (isSigDocConstantTbl(sig, x, y)) {
         return inferDocConstantTblType(T(x, env), T(y, env));
-    else if (isSigDocWriteTbl(sig, x, y, z, u))
+    } else if (isSigDocWriteTbl(sig, x, y, z, u)) {
         return inferDocWriteTblType(T(x, env), T(y, env), T(z, env), T(u, env));
-    else if (isSigDocAccessTbl(sig, x, y))
+    } else if (isSigDocAccessTbl(sig, x, y)) {
         return inferDocAccessTblType(T(x, env), T(y, env));
+    }
 
     else if (isSigSelect2(sig, sel, s1, s2)) {
         SimpleType *st1, *st2, *stsel;
@@ -705,7 +728,8 @@ static Type inferSigType(Tree sig, Tree env)
                               st1->variability() | st2->variability() | stsel->variability(),
                               st1->computability() | st2->computability() | stsel->computability(),
                               st1->vectorability() | st2->vectorability() | stsel->vectorability(),
-                              st1->boolean() | st2->boolean(), itv::reunion(st1->getInterval(), st2->getInterval()));
+                              st1->boolean() | st2->boolean(),
+                              itv::reunion(st1->getInterval(), st2->getInterval()));
     }
 
     else if (isNil(sig)) {
@@ -722,10 +746,11 @@ static Type inferSigType(Tree sig, Tree env)
         Type     t2 = T(max, env);
         Type     t3 = T(cur, env);
         interval i3 = t3->getInterval();
-        interval iEnd;
+        interval iEnd(NAN, NAN);
         constSig2double(min);
         if (i3.isValid()) {
-            iEnd = interval(std::max(i3.lo(), constSig2double(min)), std::min(i3.hi(), constSig2double(max)));
+            iEnd = interval(std::max(i3.lo(), constSig2double(min)),
+                            std::min(i3.hi(), constSig2double(max)));
         } else {
             iEnd = interval(constSig2double(min), constSig2double(max));
         }
@@ -744,6 +769,10 @@ static Type inferSigType(Tree sig, Tree env)
         // change this part   ^^^^^ once there are interval bounds depending on signal type
     }
 
+    else if (isSigRegister(sig, &i, s1)) {
+        return T(s1, env);
+    }
+
     // unrecognized signal here
     cerr << "ASSERT : when compiling, unrecognized signal : " << ppsig(sig, MAX_ERROR_SIZE) << endl;
     faustassert(false);
@@ -765,8 +794,10 @@ static Type inferProjType(Type t, int i, int vec)
                     ->promoteVariability(t->variability())
                     ->promoteComputability(t->computability())
                     ->promoteVectorability(vec /*t->vectorability()*/);
- 
-    if (vec == kVect) temp = vecCast(temp);
+
+    if (vec == kVect) {
+        temp = vecCast(temp);
+    }
     return temp;
 }
 
@@ -799,13 +830,13 @@ static Type inferWriteTableType(Type tbl, Type wi, Type ws)
     TRACE(cerr << gGlobal->TABBER << "inferring write table type : wi type = " << wi << endl);
     TRACE(cerr << gGlobal->TABBER << "inferring write table type : wd type = " << ws << endl);
 
-    int      n   = ws->nature();
-    int      b   = ws->boolean();
-    int      v   = wi->variability() | ws->variability();
-    int      c   = wi->computability() | ws->computability();
-    int      vec = wi->vectorability() | ws->vectorability();
+    int n   = ws->nature();
+    int b   = ws->boolean();
+    int v   = wi->variability() | ws->variability();
+    int c   = wi->computability() | ws->computability();
+    int vec = wi->vectorability() | ws->vectorability();
     // Interval is the reunion of tbl (and its init signal) and ws
-    interval i   = itv::reunion(tbl->getInterval(), ws->getInterval());
+    interval i = itv::reunion(tbl->getInterval(), ws->getInterval());
     TRACE(cerr << gGlobal->TABBER << "infering write table type : n="
                << "NR"[n] << ", v="
                << "KB?S"[v] << ", c="
@@ -834,12 +865,12 @@ static Type inferReadTableType(Type tbl, Type ri)
         error << "ERROR : inferring read table type, no read index type : " << ri << endl;
         throw faustexception(error.str());
     }
- 
+
     Type temp = makeSimpleType(tbl->nature(), tbl->variability() | ri->variability(),
                                tbl->computability() | ri->computability(),
-                               tbl->vectorability() | ri->vectorability(),
-                               tbl->boolean(), tbl->getInterval());
-    
+                               tbl->vectorability() | ri->vectorability(), tbl->boolean(),
+                               tbl->getInterval());
+
     return temp;
 }
 
@@ -852,11 +883,12 @@ static Type inferDocConstantTblType(Type size, Type init)
 static Type inferDocWriteTblType(Type size, Type init, Type widx, Type wsig)
 {
     checkKonst(checkInt(checkInit(size)));
-    Type temp = init->promoteVariability(kSamp)         // difficult to tell, therefore kSamp to be safe
-                    ->promoteComputability(widx->computability() | wsig->computability())
-                    ->promoteVectorability(kScal)       // difficult to tell, therefore kScal to be safe
-                    ->promoteNature(wsig->nature())     // nature of the initial and written signal
-                    ->promoteBoolean(wsig->boolean());  // booleanity of the initial and written signal
+    Type temp =
+        init->promoteVariability(kSamp)  // difficult to tell, therefore kSamp to be safe
+            ->promoteComputability(widx->computability() | wsig->computability())
+            ->promoteVectorability(kScal)       // difficult to tell, therefore kScal to be safe
+            ->promoteNature(wsig->nature())     // nature of the initial and written signal
+            ->promoteBoolean(wsig->boolean());  // booleanity of the initial and written signal
     return temp;
 }
 
@@ -920,8 +952,8 @@ static Type inferFFType(Tree ff, Tree ls, Tree env)
             ls = tl(ls);
         }
         // but the result type is defined by the function
-        return makeSimpleType(ffrestype(ff), t->variability(), t->computability(), t->vectorability(), t->boolean(),
-                              interval());
+        return makeSimpleType(ffrestype(ff), t->variability(), t->computability(),
+                              t->vectorability(), t->boolean(), interval());
     }
 }
 
@@ -957,10 +989,10 @@ static Type inferFVarType(Tree type)
 static Type inferWaveformType(Tree wfsig, Tree env)
 {
     // start with the first item interval
-    Tree   v     = wfsig->branch(0);
-    bool   iflag1 = isInt(v->node());
-    int    n     = wfsig->arity();
-    interval res = (iflag1) ? gAlgebra.IntNum(tree2int(v)) : gAlgebra.FloatNum(tree2double(v));
+    Tree     v      = wfsig->branch(0);
+    bool     iflag1 = isInt(v->node());
+    int      n      = wfsig->arity();
+    interval res    = (iflag1) ? gAlgebra.IntNum(tree2int(v)) : gAlgebra.FloatNum(tree2double(v));
     T(v, env);
 
     // loop for remaining items
@@ -969,7 +1001,8 @@ static Type inferWaveformType(Tree wfsig, Tree env)
         T(v, env);
         // compute interval
         bool iflag2 = isInt(v->node());
-        res = itv::reunion(res, iflag2 ? gAlgebra.IntNum(tree2int(v)) : gAlgebra.FloatNum(tree2double(v)));
+        res         = itv::reunion(
+            res, iflag2 ? gAlgebra.IntNum(tree2int(v)) : gAlgebra.FloatNum(tree2double(v)));
         iflag1 &= iflag2;
     }
 
@@ -984,6 +1017,8 @@ static Type inferXType(Tree sig, Tree env)
     xtended*     p = (xtended*)getUserData(sig);
     vector<Type> vt;
 
-    for (int i = 0; i < sig->arity(); i++) vt.push_back(T(sig->branch(i), env));
+    for (int i = 0; i < sig->arity(); i++) {
+        vt.push_back(T(sig->branch(i), env));
+    }
     return p->inferSigType(vt);
 }
