@@ -1,7 +1,7 @@
 /************************************************************************
  ************************************************************************
     FAUST compiler
-    Copyright (C) 2003-2018 GRAME, Centre National de Creation Musicale
+    Copyright (C) 2003-2024 GRAME, Centre National de Creation Musicale
     ---------------------------------------------------------------------
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -81,6 +81,7 @@ storage of trees.
 #include <fstream>
 
 #include "exception.hh"
+#include "global.hh"
 #include "tree.hh"
 
 using namespace std;
@@ -89,20 +90,24 @@ using namespace std;
 #pragma warning(disable : 4800)
 #endif
 
-#define ERROR(s, t)                     \
-{                                       \
-    stringstream error;                 \
-    error << s << *t << endl;           \
-    throw faustexception(error.str());  \
-}
+#define ERROR(s, t)                        \
+    {                                      \
+        stringstream error;                \
+        error << s << *t << endl;          \
+        throw faustexception(error.str()); \
+    }
 
-Tree         CTree::gHashTable[kHashTableSize];
-bool         CTree::gDetails       = false;
-unsigned int CTree::gVisitTime     = 0;
-size_t       CTree::gSerialCounter = 0;
+Tree         CTreeBase::gHashTable[kHashTableSize];
+bool         CTreeBase::gDetails       = false;
+unsigned int CTreeBase::gVisitTime     = 0;
+size_t       CTreeBase::gSerialCounter = 0;
+
+int               CDTree::kBlockSize;
+Tree              CDTree::gAllocatedBlock = nullptr;
+std::vector<Tree> CDTree::gAllocatedBlocks;
 
 // Constructor : add the tree to the hash table
-CTree::CTree(size_t hk, const Node& n, const tvec& br)
+CTreeBase::CTreeBase(size_t hk, const Node& n, const tvec& br)
     : fNode(n),
       fType(0),
       fHashKey(hk),
@@ -117,53 +122,39 @@ CTree::CTree(size_t hk, const Node& n, const tvec& br)
     gHashTable[j] = this;
 }
 
-// Destructor : remove the tree from the hash table
-CTree::~CTree()
+// Destructor
+CTreeBase::~CTreeBase()
 {
-    int  i = fHashKey % kHashTableSize;
-    Tree t = gHashTable[i];
-
-    // printf("Delete of "); this->print(); printf("\n");
-    if (t == this) {
-        gHashTable[i] = fNext;
-    } else {
-        Tree p = nullptr;
-        while (t != this) {
-            p = t;
-            t = t->fNext;
-        }
-        faustassert(p);
-        p->fNext = fNext;
-    }
+    /*
+     Remove the tree from the hash table is not needed
+     since all pointers are either managed using the Garbageable model
+     or with CDTree "successive pointers" allocation model.
+     */
 }
 
 // equivalence
-bool CTree::equiv(const Node& n, const tvec& br) const
+bool CTreeBase::equiv(const Node& n, const tvec& br) const
 {
     return (fNode == n) && (fBranch == br);
 }
 
-size_t CTree::calcTreeHash(const Node& n, const tvec& br)
+size_t CTreeBase::calcTreeHash(const Node& n, const tvec& br)
 {
-    size_t               hk = size_t(n.getPointer());
-    tvec::const_iterator b  = br.begin();
-    tvec::const_iterator z  = br.end();
-
-    while (b != z) {
-        hk = (hk << 1) ^ (hk >> 20) ^ ((*b)->fHashKey);
-        ++b;
+    size_t hk = std::hash<void*>()(n.getPointer());
+    for (const auto& ptr : br) {
+        // Taken from by boost::hash_combine
+        hk = hk ^ (ptr->fHashKey + 0x9e3779b9 + (hk << 6) + (hk >> 2));
     }
     return hk;
 }
 
-Tree CTree::make(const Node& n, int ar, Tree* tbl)
+Tree CTreeBase::make(const Node& n, int ar, Tree* tbl)
 {
-    tvec br(ar);
-    for (int i = 0; i < ar; i++) br[i] = tbl[i];
-    return CTree::make(n, br);
+    vector<Tree> br(tbl, tbl + ar);
+    return CTreeBase::make(n, br);
 }
 
-Tree CTree::make(const Node& n, const tvec& br)
+Tree CTreeBase::make(const Node& n, const tvec& br)
 {
     size_t hk = calcTreeHash(n, br);
     Tree   t  = gHashTable[hk % kHashTableSize];
@@ -171,10 +162,17 @@ Tree CTree::make(const Node& n, const tvec& br)
     while (t && !t->equiv(n, br)) {
         t = t->fNext;
     }
-    return (t) ? t : new CTree(hk, n, br);
+
+    if (t) {
+        return t;
+    } else if (global::isDebug("FAUST_DTREE")) {
+        return new CDTree(hk, n, br);
+    } else {
+        return new CTree(hk, n, br);
+    }
 }
 
-ostream& CTree::print(ostream& fout) const
+ostream& CTreeBase::print(ostream& fout) const
 {
     if (gDetails) {
         // print the adresse of the tree
@@ -195,7 +193,7 @@ ostream& CTree::print(ostream& fout) const
     return fout;
 }
 
-void CTree::control()
+void CTreeBase::control()
 {
     printf("\ngHashTable Content :\n\n");
     for (int i = 0; i < kHashTableSize; i++) {
@@ -213,14 +211,32 @@ void CTree::control()
     printf("\nEnd gHashTable\n");
 }
 
-void CTree::init()
+void CTreeBase::init()
 {
     gSerialCounter = 0;
-    gVisitTime = 0;
-    gDetails = false;
+    gVisitTime     = 0;
+    gDetails       = false;
     memset(gHashTable, 0, sizeof(Tree) * kHashTableSize);
 }
 
+void CDTree::init()
+{
+    kBlockSize      = global::getDebug("FAUST_DTREE_SIZE", 1024);
+    gAllocatedBlock = nullptr;
+    gSerialCounter  = 0;
+    gVisitTime      = 0;
+    gDetails        = false;
+    memset(gHashTable, 0, sizeof(Tree) * kHashTableSize);
+}
+
+void CDTree::cleanup()
+{
+    for (const auto& it : gAllocatedBlocks) {
+        delete[] it;
+    }
+    gAllocatedBlocks.clear();
+}
+
 // if t has a node of type int, return it, or float, return casted to int, otherwise error
 LIBFAUST_API int tree2int(Tree t)
 {
@@ -358,7 +374,7 @@ LIBFAUST_API void* getUserData(Tree t)
     if (isSym(t->node(), &s)) {
         return getUserData(s);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -366,10 +382,10 @@ LIBFAUST_API void* getUserData(Tree t)
  * export the properties of a CTree as two vectors, one for the keys
  * and one for the associated values
  */
-void CTree::exportProperties(vector<Tree>& keys, vector<Tree>& values)
+void CTreeBase::exportProperties(vector<Tree>& keys, vector<Tree>& values)
 {
-    for (plist::const_iterator p = fProperties.begin(); p != fProperties.end(); p++) {
-        keys.push_back(p->first);
-        values.push_back(p->second);
+    for (const auto& it : fProperties) {
+        keys.push_back(it.first);
+        values.push_back(it.second);
     }
 }
