@@ -1,6 +1,6 @@
 /************************************************************************
  FAUST Architecture File
- Copyright (C) 2012-2023 GRAME, Centre National de Creation Musicale
+ Copyright (C) 2012-2024 GRAME, Centre National de Creation Musicale
  ---------------------------------------------------------------------
  This Architecture section is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
@@ -74,12 +74,6 @@ struct FaustPluginMeta : public Meta
     }
 };
 
-static const char* getCodeSize()
-{
-    int tmp;
-    return (sizeof(&tmp) == 8) ? "64 bits" : "32 bits";
-}
-
 #ifdef __APPLE__
 
 #include <CoreFoundation/CoreFoundation.h>
@@ -103,9 +97,14 @@ static string getTarget()
 
 // Returns the serial number as a CFString.
 // It is the caller's responsibility to release the returned CFString when done with it.
+
+#if (MAC_OS_X_VERSION_MAX_ALLOWED < 120000) // Before macOS 12 Monterey
+    #define kIOMainPortDefault kIOMasterPortDefault
+#endif
+
 static string getSerialNumber()
 {
-    io_service_t platformExpert = IOServiceGetMatchingService(kIOMasterPortDefault, IOServiceMatching("IOPlatformExpertDevice"));
+    io_service_t platformExpert = IOServiceGetMatchingService(kIOMainPortDefault, IOServiceMatching("IOPlatformExpertDevice"));
     
     if (platformExpert) {
         CFTypeRef serialNumberAsCFString =
@@ -274,18 +273,26 @@ void faustgen_factory::free_dsp_factory()
         for (const auto& it : fInstances) {
             it->free_dsp();
         }
-        deleteDSPFactory(fDSPfactory);
+    #ifdef INTERP_BACKEND
+        deleteInterpreterDSPFactory(static_cast<interpreter_dsp_factory*>(fDSPfactory));
+    #else
+        deleteDSPFactory(static_cast<llvm_dsp_factory*>(fDSPfactory));
+    #endif
         fDSPfactory = nullptr;
     }
     unlock_ui();
     unlock_audio();
 }
 
-llvm_dsp_factory* faustgen_factory::create_factory_from_bitcode()
+dsp_factory* faustgen_factory::create_factory_from_bitcode()
 {
     // Alternate model using machine code
     string error_msg;
-    llvm_dsp_factory* factory = readDSPFactoryFromMachine(*fBitCode, getTarget(), error_msg);
+#ifdef INTERP_BACKEND
+    dsp_factory* factory = readInterpreterDSPFactoryFromBitcode(*fBitCode, error_msg);
+#else
+    dsp_factory* factory = readDSPFactoryFromMachine(*fBitCode, getTarget(), error_msg);
+#endif
     if (factory) {
         // Reset fSoundUI with the new factory getIncludePathnames
         delete fSoundUI;
@@ -302,7 +309,7 @@ llvm_dsp_factory* faustgen_factory::create_factory_from_bitcode()
     return factory;
 }
 
-llvm_dsp_factory* faustgen_factory::create_factory_from_sourcecode()
+dsp_factory* faustgen_factory::create_factory_from_sourcecode()
 {
     char name_app[64];
     snprintf(name_app, 64, "faustgen-%d", fFaustNumber);
@@ -328,25 +335,25 @@ llvm_dsp_factory* faustgen_factory::create_factory_from_sourcecode()
     if (!generateAuxFilesFromString(name_app, *fSourceCode, fCompileOptions.size(), argv, error_msg)) {
         post("Generate SVG error : %s", error_msg.c_str());
     }
-    
-    llvm_dsp_factory* factory = createDSPFactoryFromString(name_app, *fSourceCode, fCompileOptions.size(), argv, getTarget(), error_msg, fOptLevel);
-    
+#ifdef INTERP_BACKEND
+    dsp_factory* factory = createInterpreterDSPFactoryFromString(name_app, *fSourceCode, fCompileOptions.size(), argv, error_msg);
+#else
+    dsp_factory* factory = createDSPFactoryFromString(name_app, *fSourceCode, fCompileOptions.size(), argv, getTarget(), error_msg, fOptLevel);
+#endif
+
     if (factory) {
         // Reset fSoundUI with the new factory getIncludePathnames
         delete fSoundUI;
         fSoundUI = new SoundUI(factory->getIncludePathnames(), -1, nullptr, true);
         /*
-         std::vector<std::string> sound_directories = factory->getIncludePathnames();
-         for (int i = 0; i < sound_directories.size(); i++) {
+        std::vector<std::string> sound_directories = factory->getIncludePathnames();
+        for (int i = 0; i < sound_directories.size(); i++) {
             post("sound_directories %d %s", i, sound_directories[i].c_str());
-         }
+        }
         */
         return factory;
     } else {
-        // Update all instances
-        for (const auto& it : fInstances) {
-            //it->hilight_on();
-        }
+        // Hilight the error in the patch window
         if (fInstances.begin() != fInstances.end()) {
             (*fInstances.begin())->hilight_error(error_msg);
         }
@@ -420,7 +427,12 @@ llvm_dsp_factory* faustgen_factory::create_factory_from_sourcecode()
     }
     
     // Otherwise creates default DSP keeping the same input/output number
+#ifdef INTERP_BACKEND
+    fDSPfactory = createInterpreterDSPFactoryFromString("default", DEFAULT_CODE, 0, 0, error);
+#else
     fDSPfactory = createDSPFactoryFromString("default", DEFAULT_CODE, 0, 0, getTarget(), error, 0);
+#endif
+    
     dsp = create_dsp_instance();
     post("Allocation of default DSP succeeded, %i input(s), %i output(s)", dsp->getNumInputs(), dsp->getNumOutputs());
     
@@ -639,7 +651,11 @@ void faustgen_factory::appendtodictionary(t_dictionary* d)
     // Write bitcode
     if (fDSPfactory) {
         // Alternate model using machine code
-        string machinecode = writeDSPFactoryToMachine(fDSPfactory, getTarget());
+    #ifdef INTERP_BACKEND
+        string machinecode = writeInterpreterDSPFactoryToBitcode(static_cast<interpreter_dsp_factory*>(fDSPfactory));
+    #else
+        string machinecode = writeDSPFactoryToMachine(static_cast<llvm_dsp_factory*>(fDSPfactory), getTarget());
+    #endif
         dictionary_appendlong(d, gensym("machinecode_size"), machinecode.size());
         dictionary_appendstring(d, gensym("machinecode"), machinecode.c_str());
     }
@@ -689,8 +705,12 @@ void faustgen_factory::display_svg()
         post("SVG diagram not available, recompile to produce it");
         
         // Force recompilation to produce it
-        llvm_dsp_factory* factory = create_factory_from_sourcecode();
-        deleteDSPFactory(factory);
+        dsp_factory* factory = create_factory_from_sourcecode();
+    #ifdef INTERP_BACKEND
+        deleteInterpreterDSPFactory(static_cast<interpreter_dsp_factory*>(factory));
+    #else
+        deleteDSPFactory(static_cast<llvm_dsp_factory*>(factory));
+    #endif
         
         // Open the SVG diagram file inside a web browser
         open_svg();
@@ -700,24 +720,29 @@ void faustgen_factory::display_svg()
 bool faustgen_factory::open_file(const char* file)
 {
     char command[512];
-#ifdef WIN32
-    snprintf(command, 512, "start \"\" \"%s%s\"", (*fLibraryPath.begin()).c_str(), file);
-#else
-    snprintf(command, 512, "open \"%s%s\"", (*fLibraryPath.begin()).c_str(), file);
-#endif
-    post(command);
-    return (system(command) == 0);
+    for (const auto& it : fLibraryPath) {
+    #ifdef WIN32
+        snprintf(command, 512, "start \"\" \"%s%s\"", it.c_str(), file);
+    #else
+        snprintf(command, 512, "open \"%s%s\"", it.c_str(), file);
+    #endif
+        if (system(command) == 0) return true;
+    }
+    return false;
 }
 
 bool faustgen_factory::open_file(const char* appl, const char* file)
 {
     char command[512];
-#ifdef WIN32
-    snprintf(command, 512, "start \"\" %s \"%s%s\"", appl, (*fLibraryPath.begin()).c_str(), file);
-#else
-    snprintf(command, 512, "open -a %s \"%s%s\"", appl, (*fLibraryPath.begin()).c_str(), file);
-#endif
-    return (system(command) == 0);
+    for (const auto& it : fLibraryPath) {
+    #ifdef WIN32
+        snprintf(command, 512, "start \"\" %s \"%s%s\"", appl, it.c_str(), file);
+    #else
+        snprintf(command, 512, "open -a %s \"%s%s\"", appl, it.c_str(), file);
+    #endif
+        if (system(command) == 0) return true;
+    }
+    return false;
 }
 
 void faustgen_factory::display_documentation()
@@ -738,9 +763,7 @@ void faustgen_factory::display_libraries_aux(const char* lib)
     int i = 0;
     
     while ((appl = TEXT_APPL_LIST[i++]) && (strcmp(appl, "") != 0)) {
-        if (open_file(appl, lib)) {
-            break;
-        }
+        if (open_file(appl, lib)) break;
     }
 }
 
@@ -748,91 +771,52 @@ void faustgen_factory::display_libraries()
 {
     // Open the libraries
 #ifdef WIN32
-    open_file(FAUST_PDF_LIBRARY);
-    open_file("all.lib");
-    open_file("aanl.lib");
-    open_file("analyzers.lib");
-    open_file("basics.lib");
-    open_file("compressors.lib");
-    open_file("delays.lib");
-    open_file("demos.lib");
-    open_file("double.lib");
-    open_file("dx7.lib");
-    open_file("envelopes.lib");
-    open_file("filters.lib");
-    open_file("fds.lib");
-    open_file("hoa.lib");
-    open_file("instruments.lib");
-    open_file("interpolators.lib");
-    open_file("maths.lib");
-    open_file("maxmsp.lib");
-    open_file("mi.lib");
-    open_file("misceffects.lib");
-    open_file("noises.lib");
-    open_file("oscillators.lib");
-    open_file("phaflangers.lib");
-    open_file("physmodels.lib");
-    open_file("platform.lib");
-    open_file("quantizers.lib");
-    open_file("reducemaps.lib");
-    open_file("reverbs.lib");
-    open_file("routes.lib");
-    open_file("runtime.lib");
-    open_file("sf.lib");
-    open_file("signals.lib");
-    open_file("soundfiles.lib");
-    open_file("spats.lib");
-    open_file("stdfaust.lib");
-    open_file("synths.lib");
-    open_file("tonestacks.lib");
-    open_file("tubes.lib");
-    open_file("vaeffects.lib");
-    open_file("version.lib");
-    open_file("wdmodels.lib");
-    open_file("webaudio.lib");
+    #define OPEN_FILE open_file
+    OPEN_FILE(FAUST_PDF_LIBRARY);
 #else
-    display_libraries_aux("all.lib");
-    display_libraries_aux("aanl.lib");
-    display_libraries_aux("analyzers.lib");
-    display_libraries_aux("basics.lib");
-    display_libraries_aux("compressors.lib");
-    display_libraries_aux("delays.lib");
-    display_libraries_aux("demos.lib");
-    display_libraries_aux("double.lib");
-    display_libraries_aux("dx7.lib");
-    display_libraries_aux("envelopes.lib");
-    display_libraries_aux("filters.lib");
-    display_libraries_aux("fds.lib");
-    display_libraries_aux("hoa.lib");
-    display_libraries_aux("instruments.lib");
-    display_libraries_aux("interpolators.lib");
-    display_libraries_aux("maths.lib");
-    display_libraries_aux("maxmsp.lib");
-    display_libraries_aux("mi.lib");
-    display_libraries_aux("misceffects.lib");
-    display_libraries_aux("noises.lib");
-    display_libraries_aux("oscillators.lib");
-    display_libraries_aux("phaflangers.lib");
-    display_libraries_aux("physmodels.lib");
-    display_libraries_aux("platform.lib");
-    display_libraries_aux("quantizers.lib");
-    display_libraries_aux("reducemaps.lib");
-    display_libraries_aux("reverbs.lib");
-    display_libraries_aux("routes.lib");
-    display_libraries_aux("runtime.lib");
-    display_libraries_aux("sf.lib");
-    display_libraries_aux("signals.lib");
-    display_libraries_aux("soundfiles.lib");
-    display_libraries_aux("spats.lib");
-    display_libraries_aux("stdfaust.lib");
-    display_libraries_aux("synths.lib");
-    display_libraries_aux("tonestacks.lib");
-    display_libraries_aux("tubes.lib");
-    display_libraries_aux("vaeffects.lib");
-    display_libraries_aux("version.lib");
-    display_libraries_aux("wdmodels.lib");
-    display_libraries_aux("webaudio.lib");
+    #define OPEN_FILE display_libraries_aux
 #endif
+    OPEN_FILE("all.lib");
+    OPEN_FILE("aanl.lib");
+    OPEN_FILE("analyzers.lib");
+    OPEN_FILE("basics.lib");
+    OPEN_FILE("compressors.lib");
+    OPEN_FILE("delays.lib");
+    OPEN_FILE("demos.lib");
+    OPEN_FILE("double.lib");
+    OPEN_FILE("dx7.lib");
+    OPEN_FILE("envelopes.lib");
+    OPEN_FILE("filters.lib");
+    OPEN_FILE("fds.lib");
+    OPEN_FILE("hoa.lib");
+    OPEN_FILE("instruments.lib");
+    OPEN_FILE("interpolators.lib");
+    OPEN_FILE("maths.lib");
+    OPEN_FILE("maxmsp.lib");
+    OPEN_FILE("mi.lib");
+    OPEN_FILE("misceffects.lib");
+    OPEN_FILE("noises.lib");
+    OPEN_FILE("oscillators.lib");
+    OPEN_FILE("phaflangers.lib");
+    OPEN_FILE("physmodels.lib");
+    OPEN_FILE("platform.lib");
+    OPEN_FILE("quantizers.lib");
+    OPEN_FILE("reducemaps.lib");
+    OPEN_FILE("reverbs.lib");
+    OPEN_FILE("routes.lib");
+    OPEN_FILE("runtime.lib");
+    OPEN_FILE("sf.lib");
+    OPEN_FILE("signals.lib");
+    OPEN_FILE("soundfiles.lib");
+    OPEN_FILE("spats.lib");
+    OPEN_FILE("stdfaust.lib");
+    OPEN_FILE("synths.lib");
+    OPEN_FILE("tonestacks.lib");
+    OPEN_FILE("tubes.lib");
+    OPEN_FILE("vaeffects.lib");
+    OPEN_FILE("version.lib");
+    OPEN_FILE("wdmodels.lib");
+    OPEN_FILE("webaudio.lib");
 }
 
 void faustgen_factory::update_sourcecode(int size, char* source_code)
@@ -840,11 +824,6 @@ void faustgen_factory::update_sourcecode(int size, char* source_code)
     // Recompile only if text has been changed
     if (strcmp(source_code, *fSourceCode) != 0) {
         
-        // Update all instances
-        for (const auto& it : fInstances) {
-            //it->hilight_off();
-        }
-        
         // Delete the existing Faust module
         free_dsp_factory();
         
@@ -1067,4 +1046,4 @@ void faustgen_factory::compileoptions(long inlet, t_symbol* s, long argc, t_atom
             it->update_sourcecode();
         }
     }
-}
\ No newline at end of file
+}
