@@ -1,6 +1,6 @@
 /************************************************************************
  FAUST Architecture File
- Copyright (C) 2012-2023 GRAME, Centre National de Creation Musicale
+ Copyright (C) 2012-2024 GRAME, Centre National de Creation Musicale
  ---------------------------------------------------------------------
  This Architecture section is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
@@ -57,8 +57,6 @@
 #include "jgraphics.h"
 #include "ext_drag.h"
 
-#define FAUSTGEN_VERSION "1.69"
-
 #include "faustgen_factory.h"
 
 //====================
@@ -80,7 +78,8 @@ class faustgen : public MspCpp5<faustgen> {
         OSCUI* fOSCUI;                  // OSC UI
         SaveUI* fSavedUI;               // Save/load current value, reset to init value
     
-        ::dsp* fDSP;                    // LLVM Faust dsp
+        ::dsp* fDSP;                    // JIT compiled Faust dsp
+        ::dsp* fMCDSP;                  // Multi-channels adapted
         t_object* fEditor;              // Text editor object
         bool fMute;                     // DSP mute state
         static t_jrgba gDefaultColor;   // Color of the object to be used when restoring default color
@@ -106,7 +105,6 @@ class faustgen : public MspCpp5<faustgen> {
         void dsp_status(const char* mess);
         t_pxobject* check_dac();
         void create_jsui();
-        void update_outputs();
         
         bool allocate_factory(const std::string& effect_name);
         
@@ -124,9 +122,7 @@ class faustgen : public MspCpp5<faustgen> {
         faustgen(t_symbol* sym, long ac, t_atom* av);
         
         void update_sourcecode();
-        
-        void hilight_on();
-        void hilight_off();
+    
         void hilight_error(const std::string& error);
         
         // Called upon deleting the object inside the patcher
@@ -154,6 +150,8 @@ class faustgen : public MspCpp5<faustgen> {
         void librarypath(long inlet, t_symbol* s);
         
         void mute(long inlet, long mute);
+    
+        long multichanneloutputs(long outletindex);
         
         // Called when saving the Max patcher, this function saves the necessary
         // data inside the json file (faust sourcecode)
