@@ -41,8 +41,14 @@
 #include "faust/gui/MapUI.h"
 #include "faust/misc.h"
 
+#define MEMORY_READER
+#include "faust/gui/SoundUI.h"
+
 using namespace std;
 
+static MemoryReader* memory_reader = new MemoryReader();
+static SoundUI* sound_ui = new SoundUI("", -1, memory_reader, (sizeof(FAUSTFLOAT) == sizeof(double)));
+
 static void printList(const vector<string>& list)
 {
     for (int i = 0; i < list.size(); i++) {
@@ -251,6 +257,9 @@ int main(int argc, char* argv[])
             exit(EXIT_FAILURE);
         }
         
+        // Soundfile setting
+        DSP->buildUserInterface(sound_ui);
+        
         if (is_control) {
             
             // Check by setting each control to min, the max, then reset to init before going to next one
